<?php

/**
 * @file
 * Common functions used in conjunction with API actions.
 */

// If allowed, need to extend the execution time for importing.
set_time_limit(3600);

/**
 * Returns boolean, creating local files.
 */
function stockunlocks_add_local_files_provider(&$api_info) {
  $flag = FALSE;
  // First read from the template file to get the contents
  // and then populate the appropiate include file.
  $file_api_full_class_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_full_dhru_template.txt';
  $dirpath = variable_get('file_private_path', conf_path() . '/files/private');
  $file_api_full_class = $dirpath . '/stockunlocks_api_dynamic/api_full_dhru.inc';
  if (file_exists($file_api_full_class_template) && file_exists($file_api_full_class)) {
    $data = file_get_contents($file_api_full_class_template);
    // Create a temporary file to hold the contents.
    $file_api_full_class_temporary = $dirpath . '/stockunlocks_api_dynamic/$file_api_full_class_temporary.txt';
    // Implicitly creates the file.
    $handle = fopen($file_api_full_class_temporary, 'w') or exit('Cannot open file:  ' . $file_api_full_class_temporary);
    $handle = fopen($file_api_full_class_temporary, "a");
    fwrite($handle, $data);
    $url = 'SUAPIURL';
    $username = 'SUAPIUSERNAME';
    $accesskey = 'SUAPIACCESSKEY';
    file_put_contents($file_api_full_class_temporary, str_replace($url, $api_info['api_url'], file_get_contents($file_api_full_class_temporary)));
    file_put_contents($file_api_full_class_temporary, str_replace($username, $api_info['api_username'], file_get_contents($file_api_full_class_temporary)));
    file_put_contents($file_api_full_class_temporary, str_replace($accesskey, $api_info['api_access_key'], file_get_contents($file_api_full_class_temporary)));
    fclose($handle);
    // Extract the new contents of the file.
    $data = file_get_contents($file_api_full_class_temporary);
    // Populate the api_full_dhru.inc with the above contents.
    $handle = fopen($file_api_full_class, "w");
    fwrite($handle, $data);
    fclose($handle);
    // Deletes the temporary file.
    unlink($file_api_full_class_temporary);
    $flag = TRUE;
  }
  return $flag;
}

/**
 * Returns boolean, removing service provider's local files.
 */
function stockunlocks_remove_local_files_provider() {
  $flag = FALSE;
  $api_info['api_url'] = 'http://reseller.website.com/';
  $api_info['api_username'] = 'username';
  $api_info['api_access_key'] = 'XXX-XXX-XXX-XXX-XXX-XXX-XXX-XXX';
  // First read from the template file to get the contents
  // and then populate the appropiate include file.
  $file_api_full_class_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_full_dhru_template.txt';
  $dirpath = variable_get('file_private_path', conf_path() . '/files/private');
  $file_api_full_class = $dirpath . '/stockunlocks_api_dynamic/api_full_dhru.inc';
  if (file_exists($file_api_full_class_template) && file_exists($file_api_full_class)) {
    $data = file_get_contents($file_api_full_class_template);
    // Create a temporary file to hold the contents.
    $file_api_full_class_temporary = $dirpath . '/stockunlocks_api_dynamic/$file_api_full_class_temporary.txt';
    // Implicitly creates the file.
    $handle = fopen($file_api_full_class_temporary, 'w') or exit('Cannot open file:  ' . $file_api_full_class_temporary);
    $handle = fopen($file_api_full_class_temporary, "a");
    fwrite($handle, $data);
    $url = 'SUAPIURL';
    $username = 'SUAPIUSERNAME';
    $accesskey = 'SUAPIACCESSKEY';
    file_put_contents($file_api_full_class_temporary, str_replace($url, $api_info['api_url'], file_get_contents($file_api_full_class_temporary)));
    file_put_contents($file_api_full_class_temporary, str_replace($username, $api_info['api_username'], file_get_contents($file_api_full_class_temporary)));
    file_put_contents($file_api_full_class_temporary, str_replace($accesskey, $api_info['api_access_key'], file_get_contents($file_api_full_class_temporary)));
    fclose($handle);
    // Extract the new contents of the file.
    $data = file_get_contents($file_api_full_class_temporary);
    // Populate the api_full_dhru.inc with the above contents.
    $handle = fopen($file_api_full_class, "w");
    fwrite($handle, $data);
    fclose($handle);
    // Deletes the temporary file.
    unlink($file_api_full_class_temporary);
    $flag = TRUE;
  }
  return $flag;
}

/**
 * Creates a Service Provider's entry in the su_api_provider table.
 *
 * @param array $api_info
 *   An associative array containing:
 *   - api_provider: The int identifying the provider.
 *   - chosengetflag: The int designating the provider for actions.
 *   - api_url: The string representing the URL of the provider.
 *   - api_username: The string representing the username for URL access.
 *   - api_access_key: The string representing the access key for URL access.
 */
function stockunlocks_add_table_provider(&$api_info) {
  $api_id = NULL;
  $api_id = db_insert('su_api_provider')->fields(array(
    'activeflag' => $api_info['api_active'],
    'sitename' => $api_info['api_site_name'],
    'url' => $api_info['api_url'],
    'apikey' => $api_info['api_access_key'],
    'username' => $api_info['api_username'],
    'notes' => $api_info['api_notes'],
  ))->execute();
  if ($api_info['api_active'] == 1) {
    drupal_set_message(t('<strong>@var</strong> API Profile created. API connection <strong>activated</strong>.', array('@var' => $api_info['api_site_name'])));
    $api_info['api_provider'] = $api_id;
    $results = stockunlocks_add_functions_provider($api_info);
  }
  else {
    drupal_set_message(t('<strong>@var</strong> API Profile created. API connection <strong>not yet activated</strong>.', array('@var' => $api_info['api_site_name'])));
  }
}

/**
 * Returns boolean when creating a Service Provider's function files.
 *
 * @param array $api_info
 *   An associative array containing:
 *   - api_provider: The int identifying the provider.
 *   - chosengetflag: The int designating the provider for actions.
 *   - api_url: The string representing the URL of the provider.
 *   - api_username: The string representing the username for URL access.
 *   - api_access_key: The string representing the access key for URL access.
 */
function stockunlocks_add_functions_provider(&$api_info) {
  $flag = FALSE;
  $flag_dup = FALSE;
  $dirpath = variable_get('file_private_path', conf_path() . '/files/private');
  // First read from the template file to get the contents,
  // create the file and then populate the appropiate include file.
  $file_api_get_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_get_template.txt';
  $file_api_class_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_dhru_template.txt';
  $file_api_functions_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_functions_template.txt';
  $file_api_switch_place_order_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_switch_place_order_template.txt';
  $file_api_switch_check_order_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_switch_check_order_template.txt';
  $file_api_class = $dirpath . '/stockunlocks_api_dynamic/api_dhru.inc';
  $file_api_functions = $dirpath . '/stockunlocks_api_dynamic/api_functions.inc';
  $file_api_switch_place_order = $dirpath . '/stockunlocks_api_dynamic/api_switch_place_order.inc';
  $file_api_switch_check_order = $dirpath . '/stockunlocks_api_dynamic/api_switch_check_order.inc';
  if (file_exists($file_api_get_template) && file_exists($file_api_class_template) && file_exists($file_api_class) && file_exists($file_api_functions_template) && file_exists($file_api_functions) && file_exists($file_api_switch_place_order_template) && file_exists($file_api_switch_check_order_template) && file_exists($file_api_switch_place_order) && file_exists($file_api_switch_check_order)) {
    $data = file_get_contents($file_api_get_template);
    // Create the api_get_n.inc and popultate it with the above contents.
    $file_api_get_n = $dirpath . '/stockunlocks_api_dynamic/api_get_' . $api_info['api_provider'] . '.inc';
    // Implicitly creates the file.
    $handle = fopen($file_api_get_n, 'w') or exit('Cannot open file:  ' . $file_api_get_n);
    $handle = fopen($file_api_get_n, "a");
    fwrite($handle, $data);
    $url = 'SUAPIURL';
    $username = 'SUAPIUSERNAME';
    $accesskey = 'SUAPIACCESSKEY';
    file_put_contents($file_api_get_n, str_replace($url, $api_info['api_url'], file_get_contents($file_api_get_n)));
    file_put_contents($file_api_get_n, str_replace($username, $api_info['api_username'], file_get_contents($file_api_get_n)));
    file_put_contents($file_api_get_n, str_replace($accesskey, $api_info['api_access_key'], file_get_contents($file_api_get_n)));
    fclose($handle);
    $data = file_get_contents($file_api_class_template);
    // Create the api_class_n.inc and popultate it with the above contents.
    $file_api_class_n = $dirpath . '/stockunlocks_api_dynamic/api_class_' . $api_info['api_provider'] . '.inc';
    // Implicitly creates the file.
    $handle = fopen($file_api_class_n, 'w') or exit('Cannot open file:  ' . $file_api_class_n);
    $handle = fopen($file_api_class_n, "a");
    fwrite($handle, $data);
    $provider = 'SUAPIPROVIDERNUM';
    $url = 'SUAPIURL';
    $username = 'SUAPIUSERNAME';
    $accesskey = 'SUAPIACCESSKEY';
    file_put_contents($file_api_class_n, str_replace($provider, $api_info['api_provider'], file_get_contents($file_api_class_n)));
    file_put_contents($file_api_class_n, str_replace($url, $api_info['api_url'], file_get_contents($file_api_class_n)));
    file_put_contents($file_api_class_n, str_replace($username, $api_info['api_username'], file_get_contents($file_api_class_n)));
    file_put_contents($file_api_class_n, str_replace($accesskey, $api_info['api_access_key'], file_get_contents($file_api_class_n)));
    fclose($handle);
    // Append values to the api_dhru.inc file.
    $matches = array();
    $api_class_entry = "\n" . 'include (\'api_class_' . $api_info['api_provider'] . '.inc\');';
    $searchfor = $api_class_entry;
    // First check to see if the entry is already there.
    // Get the file contents, assuming the file to be readable (and exists).
    $contents = file_get_contents($file_api_class);
    // Escape special characters in the query.
    $pattern = preg_quote($searchfor, '/');
    // Finalize the regular expression, matching the whole line.
    $pattern = "/^.*$pattern.*\$/m";
    // Search, and store all matching occurences in $matches.
    if (preg_match_all($pattern, $contents, $matches)) {
      $flag_dup = TRUE;
    }
    else {
      // Append values to the file.
      $handle = fopen($file_api_class, "a");
      fwrite($handle, $api_class_entry);
      fclose($handle);
    }
    $data = file_get_contents($file_api_functions_template);
    // Create the api_functions_n.inc and popultate it with the above contents.
    $file_api_functions_n = $dirpath . '/stockunlocks_api_dynamic/api_functions_' . $api_info['api_provider'] . '.inc';
    // Implicitly creates the file.
    $handle = fopen($file_api_functions_n, 'w') or exit('Cannot open file:  ' . $file_api_functions_n);
    $handle = fopen($file_api_functions_n, "a");
    fwrite($handle, $data);
    $provider = 'SUAPIPROVIDERNUM';
    file_put_contents($file_api_functions_n, str_replace($provider, $api_info['api_provider'], file_get_contents($file_api_functions_n)));
    fclose($handle);
    // Append values to the api_functions.inc file.
    $matches = array();
    $api_functions_entry = "\n" . 'include (\'api_functions_' . $api_info['api_provider'] . '.inc\');';
    $searchfor = $api_functions_entry;
    // First check to see if the entry is already there.
    // Get the file contents, assuming the file to be readable (and exists).
    $contents = file_get_contents($file_api_functions);
    // Escape special characters in the query.
    $pattern = preg_quote($searchfor, '/');
    // Finalize the regular expression, matching the whole line.
    $pattern = "/^.*$pattern.*\$/m";
    // Search, and store all matching occurences in $matches.
    if (preg_match_all($pattern, $contents, $matches)) {
      $flag_dup = TRUE;
    }
    else {
      // Append values to the file.
      $handle = fopen($file_api_functions, "a");
      fwrite($handle, $api_functions_entry);
      fclose($handle);
    }
    if (!$flag_dup) {
      $data = file_get_contents($file_api_switch_place_order_template);
      // Create a temporary file to hold the contents.
      $file_api_switch_place_order_temporary = $dirpath . '/stockunlocks_api_dynamic/$file_api_switch_place_order_temporary.txt';
      // Implicitly creates the file.
      $handle = fopen($file_api_switch_place_order_temporary, 'w') or exit('Cannot open file:  ' . $file_api_switch_place_order_temporary);
      $handle = fopen($file_api_switch_place_order_temporary, "a");
      fwrite($handle, $data);
      $provider = 'SUAPIPROVIDERNUM';
      file_put_contents($file_api_switch_place_order_temporary, str_replace($provider, $api_info['api_provider'], file_get_contents($file_api_switch_place_order_temporary)));
      fclose($handle);
      // Extract the new contents of the file.
      $data = "\n" . file_get_contents($file_api_switch_place_order_temporary);
      // Populate the api_switch_place_order.inc with the above contents.
      $handle = fopen($file_api_switch_place_order, "a");
      $switch_close = "\n" . '}';
      file_put_contents($file_api_switch_place_order, str_replace($switch_close, NULL, file_get_contents($file_api_switch_place_order)));
      fwrite($handle, $data);
      fwrite($handle, $switch_close);
      fclose($handle);
      // Deletes the temporary file.
      unlink($file_api_switch_place_order_temporary);
      $data = file_get_contents($file_api_switch_check_order_template);
      // Create a temporary file to hold the contents.
      $file_api_switch_check_order_temporary = $dirpath . '/stockunlocks_api_dynamic/$file_api_switch_check_order_temporary.txt';
      // Implicitly creates the file.
      $handle = fopen($file_api_switch_check_order_temporary, 'w') or exit('Cannot open file:  ' . $file_api_switch_check_order_temporary);
      $handle = fopen($file_api_switch_check_order_temporary, "a");
      fwrite($handle, $data);
      $provider = 'SUAPIPROVIDERNUM';
      file_put_contents($file_api_switch_check_order_temporary, str_replace($provider, $api_info['api_provider'], file_get_contents($file_api_switch_check_order_temporary)));
      fclose($handle);
      // Extract the new contents of the file.
      $data = "\n" . file_get_contents($file_api_switch_check_order_temporary);
      // Populate the api_switch_place_order.inc with the above contents.
      $handle = fopen($file_api_switch_check_order, "a");
      $switch_close = "\n" . '}';
      file_put_contents($file_api_switch_check_order, str_replace($switch_close, NULL, file_get_contents($file_api_switch_check_order)));
      fwrite($handle, $data);
      fwrite($handle, $switch_close);
      fclose($handle);
      // Deletes the temporary file.
      unlink($file_api_switch_check_order_temporary);
    }
    $flag = TRUE;
  }
  return $flag;
}

/**
 * Returns boolean after removing a Service Provider's local files.
 *
 * @param array $api_info
 *   An associative array containing:
 *   - api_provider: The int identifying the provider.
 *   - chosengetflag: The int designating the provider for actions.
 *   - api_url: The string representing the URL of the provider.
 *   - api_username: The string representing the username for URL access.
 *   - api_access_key: The string representing the access key for URL access.
 */
function stockunlocks_remove_functions_provider(&$api_info) {
  $flag = FALSE;
  $dirpath = variable_get('file_private_path', conf_path() . '/files/private');
  $file_api_class_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_dhru_template.txt';
  $file_api_get_n = $dirpath . '/stockunlocks_api_dynamic/api_get_' . $api_info['api_provider'] . '.inc';
  $file_api_class_n = $dirpath . '/stockunlocks_api_dynamic/api_class_' . $api_info['api_provider'] . '.inc';
  $file_api_functions_n = $dirpath . '/stockunlocks_api_dynamic/api_functions_' . $api_info['api_provider'] . '.inc';
  $file_api_class = $dirpath . '/stockunlocks_api_dynamic/api_dhru.inc';
  $file_api_functions = $dirpath . '/stockunlocks_api_dynamic/api_functions.inc';
  $file_api_switch_place_order_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_switch_place_order_template.txt';
  $file_api_switch_check_order_template = drupal_get_path('module', 'stockunlocks') . '/api_dynamic/api_switch_check_order_template.txt';
  $file_api_switch_place_order = $dirpath . '/stockunlocks_api_dynamic/api_switch_place_order.inc';
  $file_api_switch_check_order = $dirpath . '/stockunlocks_api_dynamic/api_switch_check_order.inc';
  if (file_exists($file_api_get_n) && file_exists($file_api_class_template) && file_exists($file_api_class) && file_exists($file_api_class_n) && file_exists($file_api_functions_n) && file_exists($file_api_switch_place_order_template) && file_exists($file_api_switch_check_order_template) && file_exists($file_api_switch_place_order) && file_exists($file_api_switch_check_order)) {
    unlink($file_api_get_n);
    unlink($file_api_class_n);
    unlink($file_api_functions_n);
    $api_class_entry = "\n" . 'include (\'api_class_' . $api_info['api_provider'] . '.inc\');';
    $api_functions_entry = "\n" . 'include (\'api_functions_' . $api_info['api_provider'] . '.inc\');';
    file_put_contents($file_api_class, str_replace($api_class_entry, NULL, file_get_contents($file_api_class)));
    file_put_contents($file_api_functions, str_replace($api_functions_entry, NULL, file_get_contents($file_api_functions)));
    $data = file_get_contents($file_api_switch_place_order_template);
    // Create a temporary file to hold the contents.
    $file_api_switch_place_order_temporary = $dirpath . '/stockunlocks_api_dynamic/$file_api_switch_place_order_temporary.txt';
    // Implicitly creates the file.
    $handle = fopen($file_api_switch_place_order_temporary, 'w') or exit('Cannot open file:  ' . $file_api_switch_place_order_temporary);
    $handle = fopen($file_api_switch_place_order_temporary, "a");
    fwrite($handle, $data);
    $provider = 'SUAPIPROVIDERNUM';
    file_put_contents($file_api_switch_place_order_temporary, str_replace($provider, $api_info['api_provider'], file_get_contents($file_api_switch_place_order_temporary)));
    fclose($handle);
    // Extract the new contents of the file.
    $data = "\n" . file_get_contents($file_api_switch_place_order_temporary);
    file_put_contents($file_api_switch_place_order, str_replace($data, NULL, file_get_contents($file_api_switch_place_order)));
    // Deletes the temporary file.
    unlink($file_api_switch_place_order_temporary);
    $data = file_get_contents($file_api_switch_check_order_template);
    // Create a temporary file to hold the contents.
    $file_api_switch_check_order_temporary = $dirpath . '/stockunlocks_api_dynamic/$file_api_switch_check_order_temporary.txt';
    // Implicitly creates the file.
    $handle = fopen($file_api_switch_check_order_temporary, 'w') or exit('Cannot open file:  ' . $file_api_switch_check_order_temporary);
    $handle = fopen($file_api_switch_check_order_temporary, "a");
    fwrite($handle, $data);
    $provider = 'SUAPIPROVIDERNUM';
    file_put_contents($file_api_switch_check_order_temporary, str_replace($provider, $api_info['api_provider'], file_get_contents($file_api_switch_check_order_temporary)));
    fclose($handle);
    // Extract the new contents of the file.
    $data = "\n" . file_get_contents($file_api_switch_check_order_temporary);
    file_put_contents($file_api_switch_check_order, str_replace($data, NULL, file_get_contents($file_api_switch_check_order)));
    // Deletes the temporary file.
    unlink($file_api_switch_check_order_temporary);
    $flag = TRUE;
  }
  return $flag;
}

/**
 * Imports unlocking services from the designated Service Provider.
 *
 * @param array $api_info
 *   An associative array containing:
 *   - api_provider: The int identifying the provider.
 *   - chosengetflag: The int designating the provider for actions.
 *   - api_url: The string representing the URL of the provider.
 *   - api_username: The string representing the username for URL access.
 *   - api_access_key: The string representing the access key for URL access.
 */
function stockunlocks_add_provider_services(&$api_info) {
  $i = 0;
  $last_processed = '';
  $to_process = count($api_info);
  // The Ubercart product attributes to be added to this product.
  $aid_array[] = array(
    'aid' => SU_AID_BRAND,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_COUNTRY,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_EMAIL_CONFIRM,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_EMAIL_RESPONSE,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_IMEI,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_MEP,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_MODEL,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_NETWORK,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_NOTES,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_PHONE_NUM,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $aid_array[] = array(
    'aid' => SU_AID_KBH,
    'default_option' => 0,
    'label' => '',
    'ordering' => '',
    'required' => '',
    'display' => '',
  );
  $services = array();

  $chosengetflag_id = db_query('SELECT ID FROM {su_api_provider} WHERE chosengetflag = :chosengetflag', array(':chosengetflag' => 1))->fetchField();

  foreach ($api_info as $key => $value) {
    // Retrieve the unlocking service details.
    $services = stockunlocks_dhru_get_imei_service_details($value);
    $services['APIPROVIDER'] = $chosengetflag_id;
    switch ($services['RESULT']) {
      case 'SUCCESS':
        // Creates the table and node entries.
        $node = new stdClass();
        $node->type = 'product';
        node_object_prepare($node);
        $node->title = html_entity_decode($services['SERVICENAME']);
        $node->cost = $services['CREDIT'];
        $node->sell_price = $services['CREDIT'];
        $node->status = 0;
        $node->promote = 0;
        $node->body[LANGUAGE_NONE][0]['value'] = $services['INFO'];
        $node->su_api_provider[LANGUAGE_NONE][0]['value'] = $services['APIPROVIDER'];
        $node->su_api_id[LANGUAGE_NONE][0]['value'] = $services['SERVICEID'];
        $node->su_process_time[LANGUAGE_NONE][0]['value'] = $services['PROCESSTIME'];
        $node->su_price_group_id[LANGUAGE_NONE][0]['value'] = $services['GROUPID'];
        $node->su_price_group_name[LANGUAGE_NONE][0]['value'] = $services['APIPROVIDER'] . '-GROUP-' . $services['GROUP'];
        $node->su_assigned_brand[LANGUAGE_NONE][0]['value'] = $services['ASSIGNEDBRAND'];
        $node->su_assigned_model[LANGUAGE_NONE][0]['value'] = $services['ASSIGNEDMODEL'];
        $node->su_assigned_network_provider[LANGUAGE_NONE][0]['value'] = $services['ASSIGNEDPROVIDER'];
        $node->su_is_mep[LANGUAGE_NONE][0]['value'] = $services['ISMEP'];
        $node->su_is_network[LANGUAGE_NONE][0]['value'] = $services['ISPROVIDER'];
        $node->su_is_model[LANGUAGE_NONE][0]['value'] = $services['ISMODEL'];
        $node->su_is_pin[LANGUAGE_NONE][0]['value'] = $services['ISPIN'];
        $node->su_is_rm_type[LANGUAGE_NONE][0]['value'] = $services['ISTYPE'];
        $node->su_is_reference[LANGUAGE_NONE][0]['value'] = $services['ISREFERENCE'];
        $node->su_is_kbh[LANGUAGE_NONE][0]['value'] = $services['ISKBH'];
        $node->su_serial_length[LANGUAGE_NONE][0]['value'] = '15';
        $node->su_is_service_tag[LANGUAGE_NONE][0]['value'] = '0';
        $node->su_is_activation[LANGUAGE_NONE][0]['value'] = '0';
        $node->language = LANGUAGE_NONE;
        node_save($node);
        $product_nid = $node->nid;
        // Need to use the unique nid as the sku/model,
        // Grab it here because it's only available after a save.
        $node->model = $product_nid;
        node_save($node);
        $last_processed = 'Service ID = ' . $services['SERVICEID'] . ', Service Name = ' . $services['SERVICENAME'];
        ++$i;
        foreach ($aid_array as $key => $value) {
          // Retrieve the stockunlocks created uc_attribute.
          $results = db_query('SELECT label, ordering, required, display FROM {uc_attributes} WHERE aid = :aid', array(':aid' => $value['aid']));
          foreach ($results as $attribute) {
            $value['label'] = $attribute->label;
            $value['ordering'] = $attribute->ordering;
            $value['required'] = $attribute->required;
            $value['display'] = $attribute->display;
          }
          $nid = db_insert('uc_product_attributes')
            ->fields(array(
              'nid' => $product_nid,
              'aid' => $value['aid'],
              'label' => $value['label'],
              'ordering' => $value['ordering'],
              'default_option' => $value['default_option'],
              'required' => $value['required'],
              'display' => $value['display'],
            ))
            ->execute();
        }
        break;

      case 'ERROR':

        break;

    }
  }

  drupal_set_message(t('# of Items processed = @var', array('@var' => $i)));
  $remain = $to_process - $i;
  drupal_set_message(t('# of Items remaining (not processed) = @var', array('@var' => $remain)));
  if (!empty($last_processed) && $last_processed != NULL) {
    drupal_set_message(t('Last Processed = @var', array('@var' => $last_processed)));
  }
  drupal_set_message(t('Click <a href="/admin/content">HERE</a> to view newly imported services.'));
}

/**
 * Returns an associative array of nids representing imported services.
 *
 * @param array $api_info
 *   An associative array containing:
 *   - api_provider: The int identifying the provider.
 *   - chosengetflag: The int designating the provider for actions.
 *   - api_url: The string representing the URL of the provider.
 *   - api_username: The string representing the username for URL access.
 *   - api_access_key: The string representing the access key for URL access.
 */
function stockunlocks_get_provider_services_nids(&$api_info) {
  $nids = array();
  // Fetch all results.
  $nids = db_select('field_data_su_api_provider', 'n')
  ->condition('n.su_api_provider_value', $api_info['api_provider'])
  ->fields('n', array('entity_id'))
  ->execute()
  ->fetchAll();
  return $nids;
}

/**
 * Unpublish the Service Provider's imported unlocking services.
 *
 * @param array $nids
 *   An indexed array of nids: the Service Provider's unlocking services.
 */
function stockunlocks_disable_provider_services_unpublish(&$nids) {
  foreach ($nids as $row) {
    $node = node_load($row->entity_id);
    node_object_prepare($node);
    $node->status = 0;
    $node->promote = 0;
    node_save($node);
  }
}

/**
 * Changes the Provider's imported unlocking services status to "offline".
 *
 * @param array $nids
 *   An indexed array of nids: the Service Provider's unlocking services.
 */
function stockunlocks_disable_provider_services_offline(&$nids) {
  foreach ($nids as $row) {
    $node = node_load($row->entity_id);
    node_object_prepare($node);
    $node->su_temp_status[LANGUAGE_NONE][0]['value'] = 0;
    node_save($node);
  }
}

/**
 * Deletes the Service Provider's imported unlocking services.
 *
 * @param array $nids
 *   An indexed array of nids: the Service Provider's unlocking services.
 */
function stockunlocks_delete_provider_services(&$nids) {
  foreach ($nids as $row) {
    node_delete($row->entity_id);
  }
}

/**
 * Deletes the Service Provider's imported brands and models.
 *
 * @param array $apiids
 *   An array of Service Provider unique identifiers.
 */
function stockunlocks_delete_provider_models(&$apiids) {
  foreach ($apiids as $apiid) {

    $results_brand = db_delete('su_service_brand')
    ->condition('api_provider', $apiid)
    ->execute();

    $results_model = db_delete('su_service_model')
    ->condition('api_provider', $apiid)
    ->execute();
  }
}

/**
 * Deletes the Service Provider's imported MEP(s).
 *
 * @param array $apiids
 *   An array of Service Provider unique identifiers.
 */
function stockunlocks_delete_provider_mep(&$apiids) {
  foreach ($apiids as $apiid) {

    $results_mep = db_delete('su_mep')
    ->condition('api_provider', $apiid)
    ->execute();
  }
}

/**
 * Deletes the Service Provider's imported countries and network providers.
 *
 * @param array $apiids
 *   An array of Service Provider unique identifiers.
 */
function stockunlocks_delete_provider_networks(&$apiids) {
  foreach ($apiids as $apiid) {

    $results_country = db_delete('su_service_country')
    ->condition('api_provider', $apiid)
    ->execute();

    $results_network = db_delete('su_service_network')
    ->condition('api_provider', $apiid)
    ->execute();
  }
}

/**
 * Imports browser selected model(s) from the designated Service Provider.
 */
function stockunlocks_add_provider_models_browser(&$table_info) {
  $results = array();
  $i = 0;
  $i_dup = 0;
  $last_processed = '';
  $to_process = count($table_info);
  drupal_set_message(t('# of Items to process = @var', array('@var' => $to_process)));

  $chosengetflag_id = db_query('SELECT ID FROM {su_api_provider} WHERE chosengetflag = :chosengetflag', array(':chosengetflag' => 1))->fetchField();

  foreach ($table_info as $key => $value) {
    $results = explode('-php-', $value);
    $api_info = array();
    $api_info['BRANDID'] = $results[0];
    $api_info['BRANDNAME'] = html_entity_decode($results[1]);
    $api_info['MODELID'] = $results[2];
    $api_info['MODELNAME'] = html_entity_decode($results[3]);
    // Creates the brand entry, if it doesn't already exist.
    $results_brand = db_query('SELECT * FROM {su_service_brand} WHERE api_provider = :api_provider AND api = :api',
                            array(
                              ':api_provider' => $chosengetflag_id,
                              ':api' => $api_info['BRANDID'],
                            ));
    if ($results_brand->rowCount() > 0) {
      // This entry already exists, so skip it.
    }
    else {
      // Creates the brand entry.
      $api_id = db_insert('su_service_brand')->fields(array(
        'Name' => $api_info['BRANDNAME'],
        'api' => $api_info['BRANDID'],
        'api_provider' => $chosengetflag_id,
        'image_link' => '',
      ))->execute();
    }
    // Creates the model entry, if it doesn't already exist.
    $results_model = db_query('SELECT * FROM {su_service_model} WHERE ID_Brand = :ID_Brand AND api = :api AND api_provider = :api_provider ',
                            array(
                              ':ID_Brand' => $api_info['BRANDID'],
                              ':api' => $api_info['MODELID'],
                              ':api_provider' => $chosengetflag_id,
                            ));
    if ($results_model->rowCount() > 0) {
      // This entry already exists, so skip it.
      ++$i_dup;
    }
    else {
      // Creates the model entry.
      $api_id = db_insert('su_service_model')->fields(array(
        'Name' => $api_info['MODELNAME'],
        'ID_Brand' => $api_info['BRANDID'],
        'api' => $api_info['MODELID'],
        'api_provider' => $chosengetflag_id,
        'image_link' => '',
      ))->execute();
      $last_processed = 'Brand ID = ' . $api_info['BRANDID'] . ', Brand Name = ' . $api_info['BRANDNAME'] . ', Model ID = ' . $api_info['MODELID'] . ', Model Name = ' . $api_info['MODELNAME'];
      ++$i;
    }
  }
  drupal_set_message(t('# of Duplicates detected = @var', array('@var' => $i_dup)));
  drupal_set_message(t('# of Items processed = @var', array('@var' => $i)));
  $remain = $to_process - $i;
  drupal_set_message(t('# of Items remaining (not processed) = @var', array('@var' => $remain)));
  if (!empty($last_processed) && $last_processed != NULL) {
    drupal_set_message(t('Last Processed = @var', array('@var' => $last_processed)));
  }
}

/**
 * Imports all model(s) from the designated Service Provider.
 */
function stockunlocks_add_provider_models_backend() {
  $services = array();
  $i = 0;
  $i_dup = 0;
  $last_processed = '';
  $to_process = '';

  $chosengetflag_id = db_query('SELECT ID FROM {su_api_provider} WHERE chosengetflag = :chosengetflag', array(':chosengetflag' => 1))->fetchField();

  $api = new StockunlocksDhruFusion();
  $api->debug = TRUE;
  $request = array();
  $para['ID'] = NULL;
  $request = $api->action('modellist', $para);
  if (is_array($request)) {
    $iterator = new RecursiveIteratorIterator(new RecursiveArrayIterator($request), RecursiveIteratorIterator::SELF_FIRST);
    foreach ($iterator as $key1 => $val1) {
      if ($key1 === 'LIST') {
        if (is_array($val1)) {
          foreach ($val1 as $key2 => $val2) {
            $tmp_id = $key2;
            if (is_array($val2)) {
              foreach ($val2 as $key3 => $val3) {
                if ($key3 === 'NAME') {
                  $tmp_name = $val3;
                }
                if ($key3 === 'MODELS') {
                  if (is_array($val3)) {
                    foreach ($val3 as $key4 => $val4) {
                      if (is_array($val4)) {
                        $tmp_model_id = '';
                        $tmp_model_name = '';
                        foreach ($val4 as $key5 => $val5) {
                          if ($key5 === 'ID') {
                            $tmp_model_id = $val5;
                          }
                          if ($key5 === 'NAME') {
                            $tmp_model_name = $val5;
                          }
                          if ($tmp_model_name != '') {
                            $services[] = array(
                              'BRANDID' => $tmp_id,
                              'BRANDNAME' => html_entity_decode($tmp_name),
                              'MODELID' => $tmp_model_id,
                              'MODELNAME' => html_entity_decode($tmp_model_name),
                            );
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  $to_process = count($services);
  drupal_set_message(t('# of Items to process = @var', array('@var' => $to_process)));
  foreach ($services as $service) {
    // Creates the beand entry, if it doesn't already exist.
    $results_brand = db_query('SELECT * FROM {su_service_brand} WHERE api_provider = :api_provider AND api = :api',
                              array(
                                ':api_provider' => $chosengetflag_id,
                                ':api' => $service['BRANDID'],
                              ));
    if ($results_brand->rowCount() > 0) {
      // This entry already exists, so skip it.
    }
    else {
      // Creates the brand entry.
      $api_id = db_insert('su_service_brand')->fields(array(
        'Name' => html_entity_decode($service['BRANDNAME']),
        'api' => $service['BRANDID'],
        'api_provider' => $chosengetflag_id,
        'image_link' => '',
      ))->execute();
    }
    // Creates the model entry, if it doesn't already exist.
    $results_model = db_query('SELECT * FROM {su_service_model} WHERE ID_Brand = :ID_Brand AND api = :api AND api_provider = :api_provider ',
                              array(
                                ':ID_Brand' => $service['BRANDID'],
                                ':api' => $service['MODELID'],
                                ':api_provider' => $chosengetflag_id,
                              ));
    if ($results_model->rowCount() > 0) {
      // This entry already exists, so skip it.
      ++$i_dup;
    }
    else {
      // Creates the model entry.
      $api_id = db_insert('su_service_model')->fields(array(
        'Name' => html_entity_decode($service['MODELNAME']),
        'ID_Brand' => $service['BRANDID'],
        'api' => $service['MODELID'],
        'api_provider' => $chosengetflag_id,
        'image_link' => '',
      ))->execute();
      $last_processed = 'Brand ID = ' . $service['BRANDID'] . ', Brand Name = ' . $service['BRANDNAME'] . ', Model ID = ' . $service['MODELID'] . ', Model Name = ' . $service['MODELNAME'];
      ++$i;
    }
  }
  drupal_set_message(t('# of Duplicates detected = @var', array('@var' => $i_dup)));
  drupal_set_message(t('# of Items processed = @var', array('@var' => $i)));
  $remain = $to_process - $i;
  drupal_set_message(t('# of Items remaining (not processed) = @var', array('@var' => $remain)));
  if (!empty($last_processed) && $last_processed != NULL) {
    drupal_set_message(t('Last Processed = @var', array('@var' => $last_processed)));
  }
}

/**
 * Imports browser selected MEP from the designated Service Provider.
 */
function stockunlocks_add_provider_mep_browser(&$table_info) {
  $results = array();
  $i = 0;
  $i_dup = 0;
  $last_processed = '';
  $to_process = count($table_info);
  drupal_set_message(t('# of Items to process = @var', array('@var' => $to_process)));

  $chosengetflag_id = db_query('SELECT ID FROM {su_api_provider} WHERE chosengetflag = :chosengetflag', array(':chosengetflag' => 1))->fetchField();

  foreach ($table_info as $key => $value) {
    $results = explode('-php-', $value);
    $api_info = array();
    $api_info['MEPID'] = $results[0];
    $api_info['MEPNAME'] = html_entity_decode($results[1]);
    // Creates the mep entry, if it doesn't already exist.
    $results_mep = db_query('SELECT * FROM {su_mep} WHERE api_provider = :api_provider AND api = :api',
                          array(
                            ':api_provider' => $chosengetflag_id,
                            ':api' => $api_info['MEPID'],
                          ));
    if ($results_mep->rowCount() > 0) {
      // This entry already exists, so skip it.
      ++$i_dup;
    }
    else {
      // Creates the brand entry.
      $api_id = db_insert('su_mep')->fields(array(
        'Name' => $api_info['MEPNAME'],
        'api' => $api_info['MEPID'],
        'api_provider' => $chosengetflag_id,
      ))->execute();
      $last_processed = 'MEP ID = ' . $api_info['MEPID'] . ', MEP Name = ' . $api_info['MEPNAME'];
      ++$i;
    }
  }
  drupal_set_message(t('# of Duplicates detected = @var', array('@var' => $i_dup)));
  drupal_set_message(t('# of Items processed = @var', array('@var' => $i)));
  $remain = $to_process - $i;
  drupal_set_message(t('# of Items remaining (not processed) = @var', array('@var' => $remain)));
  if (!empty($last_processed) && $last_processed != NULL) {
    drupal_set_message(t('Last Processed = @var', array('@var' => $last_processed)));
  }
}

/**
 * Imports all MEP from the designated Service Provider.
 */
function stockunlocks_add_provider_mep_backend() {
  $services = array();
  $i = 0;
  $i_dup = 0;
  $last_processed = '';
  $to_process = '';

  $chosengetflag_id = db_query('SELECT ID FROM {su_api_provider} WHERE chosengetflag = :chosengetflag', array(':chosengetflag' => 1))->fetchField();

  $api = new StockunlocksDhruFusion();
  // Debug on.
  $api->debug = TRUE;
  $request = array();
  $request = $api->action('meplist');
  if (is_array($request)) {
    $iterator = new RecursiveIteratorIterator(new RecursiveArrayIterator($request), RecursiveIteratorIterator::SELF_FIRST);
    foreach ($iterator as $key1 => $val1) {
      if ($key1 === 'LIST') {
        if (is_array($val1)) {
          foreach ($val1 as $key2 => $val2) {
            $tmp_id = $key2;
            if (is_array($val2)) {
              foreach ($val2 as $key3 => $val3) {
                if ($key3 === 'NAME') {
                  $tmp_mep_name = $val3;
                  if ($tmp_mep_name != '') {
                    $services[] = array(
                      'MEPID' => $tmp_id,
                      'MEPNAME' => $tmp_mep_name,
                    );
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  $to_process = count($services);
  drupal_set_message(t('# of Items to process = @var', array('@var' => $to_process)));
  foreach ($services as $service) {
    // Creates the mep entry, if it doesn't already exist.
    $results_mep = db_query('SELECT * FROM {su_mep} WHERE api_provider = :api_provider AND api = :api',
                          array(
                            ':api_provider' => $chosengetflag_id,
                            ':api' => $service['MEPID'],
                          ));
    if ($results_mep->rowCount() > 0) {
      // This entry already exists, so skip it.
      ++$i_dup;
    }
    else {
      // Creates the brand entry.
      $api_id = db_insert('su_mep')->fields(array(
        'Name' => $service['MEPNAME'],
        'api' => $service['MEPID'],
        'api_provider' => $chosengetflag_id,
      ))->execute();
      $last_processed = 'MEP ID = ' . $service['MEPID'] . ', MEP Name = ' . $service['MEPNAME'];
      ++$i;
    }
  }
  drupal_set_message(t('# of Duplicates detected = @var', array('@var' => $i_dup)));
  drupal_set_message(t('# of Items processed = @var', array('@var' => $i)));
  $remain = $to_process - $i;
  drupal_set_message(t('# of Items remaining (not processed) = @var', array('@var' => $remain)));
  if (!empty($last_processed) && $last_processed != NULL) {
    drupal_set_message(t('Last Processed = @var', array('@var' => $last_processed)));
  }
}

/**
 * Imports browser selected network provider(s).
 */
function stockunlocks_add_provider_networks_browser(&$table_info) {
  $results = array();
  $i = 0;
  $i_dup = 0;
  $last_processed = '';
  $to_process = count($table_info);
  drupal_set_message(t('# of Items to process = @var', array('@var' => $to_process)));

  $chosengetflag_id = db_query('SELECT ID FROM {su_api_provider} WHERE chosengetflag = :chosengetflag', array(':chosengetflag' => 1))->fetchField();

  foreach ($table_info as $key => $value) {
    $results = explode('-php-', $value);
    $api_info = array();
    $api_info['COUNTRYID'] = $results[0];
    $api_info['COUNTRYNAME'] = html_entity_decode($results[1]);
    $api_info['PROVIDERID'] = $results[2];
    $api_info['PROVIDERNAME'] = html_entity_decode($results[3]);
    // Create the country entry, if it doesn't already exist.
    $results_country = db_query('SELECT * FROM {su_service_country} WHERE api_provider = :api_provider AND api = :api',
                              array(
                                ':api_provider' => $chosengetflag_id,
                                ':api' => $api_info['COUNTRYID'],
                              ));
    if ($results_country->rowCount() > 0) {
      // This entry already exists, so skip it.
    }
    else {
      // Creates the country entry.
      $api_id = db_insert('su_service_country')->fields(array(
        'Name' => $api_info['COUNTRYNAME'],
        'api' => $api_info['COUNTRYID'],
        'api_provider' => $chosengetflag_id,
      ))->execute();
    }
    // Create the network provider entry, if it doesn't already exist.
    $results_network = db_query('SELECT * FROM {su_service_network} WHERE ID_Country = :ID_Country AND api = :api AND api_provider = :api_provider ',
                            array(
                              ':ID_Country' => $api_info['COUNTRYID'],
                              ':api' => $api_info['PROVIDERID'],
                              ':api_provider' => $chosengetflag_id,
                            ));
    if ($results_network->rowCount() > 0) {
      // This entry already exists, so skip it.
      ++$i_dup;
    }
    else {
      // Creates the network provider entry.
      $api_id = db_insert('su_service_network')->fields(array(
        'Name' => $api_info['PROVIDERNAME'],
        'ID_Country' => $api_info['COUNTRYID'],
        'api' => $api_info['PROVIDERID'],
        'api_provider' => $chosengetflag_id,
      ))->execute();
      $last_processed = 'Country ID = ' . $api_info['COUNTRYID'] . ', Country Name = ' . $api_info['COUNTRYNAME'] . ', Provider ID = ' . $api_info['PROVIDERID'] . ', Provider Name = ' . $api_info['PROVIDERNAME'];
      ++$i;
    }
  }
  drupal_set_message(t('# of Duplicates detected = @var', array('@var' => $i_dup)));
  drupal_set_message(t('# of Items processed = @var', array('@var' => $i)));
  $remain = $to_process - $i;
  drupal_set_message(t('# of Items remaining (not processed) = @var', array('@var' => $remain)));
  if (!empty($last_processed) && $last_processed != NULL) {
    drupal_set_message(t('Last Processed = @var', array('@var' => $last_processed)));
  }
}

/**
 * Imports all network provider(s) from the designated Service Provider.
 */
function stockunlocks_add_provider_networks_backend() {
  $services = array();
  $i = 0;
  $i_dup = 0;
  $last_processed = '';
  $to_process = '';
  $tmp_serviceid = '';
  $tmp_succ_result = '';
  $tmp_succ_msg = '';
  $tmp_err_result = '';
  $tmp_err_msg = '';

  $chosengetflag_id = db_query('SELECT ID FROM {su_api_provider} WHERE chosengetflag = :chosengetflag', array(':chosengetflag' => 1))->fetchField();

  $api = new StockunlocksDhruFusion();
  $api->debug = TRUE;
  $request = array();
  $para['ID'] = NULL;
  $request = $api->action('providerlist', $para);
  if (is_array($request)) {
    $iterator = new RecursiveIteratorIterator(new RecursiveArrayIterator($request), RecursiveIteratorIterator::SELF_FIRST);
    $tmp_serviceid = '';
    foreach ($iterator as $key1 => $val1) {
      $tmp_succ_result = '';
      $tmp_succ_msg = '';
      $tmp_err_result = '';
      $tmp_err_msg = '';
      if ($key1 === 'ID') {
        $tmp_serviceid = $val1;
      }
      if ($key1 === 'ERROR') {
        $tmp_err_result = $key1;
        $tmp_err_msg = "No Parameter 'ID' submitted, returning all Country and Provider List";
      }
      if ($key1 === 'SUCCESS') {
        $tmp_succ_result = $key1;
        $tmp_succ_msg = "Country and Provider List";
      }
      if ($key1 === 'LIST') {
        if (is_array($val1)) {
          foreach ($val1 as $key2 => $val2) {
            $tmp_id = $key2;
            if (is_array($val2)) {
              foreach ($val2 as $key3 => $val3) {
                if ($key3 === 'NAME') {
                  $tmp_name = $val3;
                }
                if ($key3 === 'PROVIDERS') {
                  if (is_array($val3)) {
                    foreach ($val3 as $key4 => $val4) {
                      if (is_array($val4)) {
                        $tmp_providername_id = '';
                        $tmp_providername = '';
                        foreach ($val4 as $key5 => $val5) {
                          if ($key5 === 'ID') {
                            $tmp_providername_id = $val5;
                          }
                          if ($key5 === 'NAME') {
                            $tmp_providername = $val5;
                          }
                          if ($tmp_providername != '') {
                            $services[] = array(
                              'COUNTRYID' => $tmp_id,
                              'COUNTRYNAME' => $tmp_name,
                              'PROVIDERID' => $tmp_providername_id,
                              'PROVIDERNAME' => $tmp_providername,
                            );
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  $to_process = count($services);
  drupal_set_message(t('# of Items to process = @var', array('@var' => $to_process)));
  foreach ($services as $service) {
    // Create the country entry, if it doesn't already exist.
    $results_country = db_query('SELECT * FROM {su_service_country} WHERE api_provider = :api_provider AND api = :api',
                              array(
                                ':api_provider' => $chosengetflag_id,
                                ':api' => $service['COUNTRYID'],
                              ));
    if ($results_country->rowCount() > 0) {
      // This entry already exists, so skip it.
    }
    else {
      // Creates the country entry.
      $api_id = db_insert('su_service_country')->fields(array(
        'Name' => html_entity_decode($service['COUNTRYNAME']),
        'api' => $service['COUNTRYID'],
        'api_provider' => $chosengetflag_id,
      ))->execute();
    }
    // Create the network provider entry, if it doesn't already exist.
    $results_network = db_query('SELECT * FROM {su_service_network} WHERE ID_Country = :ID_Country AND api = :api AND api_provider = :api_provider ',
                              array(
                                ':ID_Country' => $service['COUNTRYID'],
                                ':api' => $service['PROVIDERID'],
                                ':api_provider' => $chosengetflag_id,
                              ));
    if ($results_network->rowCount() > 0) {
      // This entry already exists, so skip it.
      ++$i_dup;
    }
    else {
      // Creates the network provider entry.
      $api_id = db_insert('su_service_network')->fields(array(
        'Name' => html_entity_decode($service['PROVIDERNAME']),
        'ID_Country' => $service['COUNTRYID'],
        'api' => $service['PROVIDERID'],
        'api_provider' => $chosengetflag_id,
      ))->execute();
      $last_processed = 'Country ID = ' . $service['COUNTRYID'] . ', Country Name = ' . $service['COUNTRYNAME'] . ', Provider ID = ' . $service['PROVIDERID'] . ', Provider Name = ' . $service['PROVIDERNAME'];
      ++$i;
    }
  }
  drupal_set_message(t('# of Duplicates detected = @var', array('@var' => $i_dup)));
  drupal_set_message(t('# of Items processed = @var', array('@var' => $i)));
  $remain = $to_process - $i;
  drupal_set_message(t('# of Items remaining (not processed) = @var', array('@var' => $remain)));
  if (!empty($last_processed) && $last_processed != NULL) {
    drupal_set_message(t('Last Processed = @var', array('@var' => $last_processed)));
  }
}

/**
 * Returns an associative array representing a specific unlocking service.
 *
 * @param string $api_action_apiid
 *   A string representation of an unlocking service's unique identifier.
 */
function stockunlocks_dhru_get_imei_service_details($api_action_apiid) {
  $api = new StockunlocksDhruFusion();
  $api->debug = TRUE;
  $request = array();
  $services = array();

  $para['ID'] = $api_action_apiid;
  $request = $api->action('getimeiservicedetails', $para);
  $i = 0;
  if (is_array($request)) {
    $iterator = new RecursiveIteratorIterator(new RecursiveArrayIterator($request), RecursiveIteratorIterator::SELF_FIRST);
    foreach ($iterator as $key1 => $val1) {
      if ($key1 === 'ID') {
        $tmp_serviceid = $val1;
      }
      if ($key1 === 'SUCCESS' || $key1 === 'ERROR') {
        $tmp_result = $key1;
        if (is_array($val1)) {
          foreach ($val1 as $key2 => $val2) {
            if (is_array($val2)) {
              $tmp_msg = '';
              foreach ($val2 as $key3 => $val3) {
                if ($key3 === 'MESSAGE') {
                  $tmp_msg = $val3;
                }
                if ($key3 === 'LIST') {
                  if (is_array($val3)) {
                    $username = '';
                    $service_name = '';
                    $credit = '';
                    $purchase_cost = '';
                    $id = '';
                    $api = '';
                    $assigned_brand = '';
                    $assigned_model = '';
                    $assigned_provider = '';
                    $listing = '';
                    $notification_mail = '';
                    $processtime = '';
                    $group_id = '';
                    $group = '';
                    $info = '';
                    $model = '';
                    $provider = '';
                    $mep = '';
                    $pin = '';
                    $kbh = '';
                    $prd = '';
                    $type = '';
                    $isalpha = '';
                    $reference = '';
                    $locks = '';
                    $imei_single = '';
                    $imei_bulk = '';
                    $imei_custom = '';
                    $imei_custom_len = '';
                    $imei_custom_name = '';
                    $imei_custom_info = '';
                    foreach ($val3 as $key4 => $val4) {
                      switch ($key4) {
                        case 'username':
                          $username = $val4;
                          break;

                        case 'service_name':
                          $service_name = $val4;
                          break;

                        case 'time':
                          $processtime = $val4;
                          break;

                        case 'credit':
                          $credit = $val4;
                          break;

                        case 'purchase_cost':
                          $purchase_cost = $val4;
                          break;

                        case 'id':
                          $id = $val4;
                          break;

                        case 'API':
                          $api = $val4;
                          break;

                        case 'assigned_model':
                          $assigned_model = $val4;
                          break;

                        case 'assigned_provider':
                          $assigned_provider = $val4;
                          break;

                        case 'group_id':
                          $group_id = $val4;
                          break;

                        case 'group':
                          $group = $val4;
                          break;

                        case 'info':
                          $info = $val4;
                          break;

                        case 'listing':
                          $listing = $val4;
                          break;

                        case 'notification_mail':
                          $notification_mail = $val4;
                          break;

                      }
                      if (is_array($val4)) {
                        foreach ($val4 as $key5 => $val5) {
                          switch ($key5) {
                            case 'model':
                              $model = $val5;
                              break;

                            case 'assigned_brand':
                              $assigned_brand = $val5;
                              break;

                            case 'provider':
                              $provider = $val5;
                              break;

                            case 'mep':
                              $mep = $val5;
                              break;

                            case 'PIN':
                              $pin = $val5;
                              break;

                            case 'KBH':
                              $kbh = $val5;
                              break;

                            case 'PRD':
                              $prd = $val5;
                              break;

                            case 'isalpha':
                              $isalpha = $val5;
                              break;

                            case 'type':
                              $type = $val5;
                              break;

                            case 'reference':
                              $reference = $val5;
                              break;

                            case 'locks':
                              $locks = $val5;
                              break;

                            case 'imei_single':
                              $imei_single = $val5;
                              break;

                            case 'imei_bulk':
                              $imei_bulk = $val5;
                              break;

                            case 'imei_custom':
                              $imei_custom = $val5;
                              break;

                            case 'imei_custom_len':
                              $imei_custom_len = $val5;
                              break;

                            case 'imei_custom_name':
                              $imei_custom_name = $val5;
                              break;

                            case 'imei_custom_info':
                              $imei_custom_info = $val5;
                              break;

                          }
                        }
                      }
                    }
                  }
                }
              }
              switch ($tmp_result) {
                case 'ERROR':
                  $services = array('RESULT' => $tmp_result, 'MESSAGE' => $tmp_msg);
                  break;

                case 'SUCCESS':
                  $services = array(
                    'RESULT' => $tmp_result,
                    'SERVICEID' => $tmp_serviceid,
                    'API' => $api,
                    'USERNAME' => $username,
                    'SERVICENAME' => $service_name,
                    'ID' => $id,
                    'ASSIGNEDBRAND' => $assigned_brand,
                    'ASSIGNEDMODEL' => $assigned_model,
                    'ASSIGNEDPROVIDER' => $assigned_provider,
                    'LISTING' => $listing,
                    'EMAIL' => $notification_mail,
                    'CREDIT' => $credit,
                    'PURCHASECOST' => $purchase_cost,
                    'PROCESSTIME' => $processtime,
                    'GROUPID' => $group_id,
                    'GROUP' => $group,
                    'INFO' => $info,
                    'ISMODEL' => $model,
                    'ISPROVIDER' => $provider,
                    'ISMEP' => $mep,
                    'ISPIN' => $pin,
                    'ISKBH' => $kbh,
                    'ISPRD' => $prd,
                    'ISALPHA' => $isalpha,
                    'ISTYPE' => $type,
                    'ISREFERENCE' => $reference,
                    'ISLOCKS' => $locks,
                    'IMEISINGLE' => $imei_single,
                    'IMEIBULK' => $imei_bulk,
                    'IMEICUSTOM' => $imei_custom,
                    'IMEICUSTOMLEN' => $imei_custom_len,
                    'IMEICUSTOMNAME' => $imei_custom_name,
                    'IMEICUSTOMINFO' => $imei_custom_info,
                  );
                  break;

              }
            }
          }
        }
      }
    }
  }
  return $services;
}
