<?php

/**
 * @file
 * Functions for processing Dhru API orders.
 */

/**
 * Returns an associative array of orders.
 */
function stockunlocks_fetch_orders_completed() {
  $order_status = 'completed';
  $order_status2 = 'payment_received';
  $payment_method = 'free_order';
  $result_orders_completed = array();
  $result_orders_completed = db_query("SELECT * FROM {uc_orders} WHERE order_status = :order_status OR (order_status = :order_status2 AND payment_method = :payment_method)",
                                      array(
                                        ':order_status' => $order_status,
                                        ':order_status2' => $order_status2,
                                        ':payment_method' => $payment_method,
                                      ));
  if ($result_orders_completed->rowCount() == 0) {
    return NULL;
  }
  else {
    return $result_orders_completed;
  }
}


/**
 * Returns an associative array of orders where order_status = su_ordered.
 */
function stockunlocks_fetch_orders_ordered() {
  $order_status = 'su_ordered';
  $result_orders_ordered = array();
  $result_orders_ordered = db_query("SELECT * FROM {uc_orders} WHERE order_status = :order_status", array(':order_status' => $order_status));
  if ($result_orders_ordered->rowCount() == 0) {
    return NULL;
  }
  else {
    return $result_orders_ordered;
  }
}

/**
 * Returns an associative array of orders, order_status = su_code_available.
 */
function stockunlocks_fetch_orders_code_available() {
  $order_status = 'su_code_available';
  $result_orders_code_available = array();
  $result_orders_code_available = db_query("SELECT * FROM {uc_orders} WHERE order_status = :order_status", array(':order_status' => $order_status));
  if ($result_orders_code_available->rowCount() == 0) {
    return NULL;
  }
  else {
    return $result_orders_code_available;
  }
}

/**
 * Implements hook_mail().
 */
function stockunlocks_mail($key, &$message, $params) {
  // Each message is associated with a language, which may or may not be the
  // current user's selected language, depending on the type of e-mail being
  // sent. This $options array is used later in the t() calls for subject
  // and body to ensure the proper translation takes effect.
  $options = array(
    'langcode' => $message['language']->language,
  );

  switch ($key) {
    // Send a simple message.
    case 'contact_message':
      $message['subject'] = t('@subject', array('@subject' => $params['subject']), $options);
      // The message body is an array, not a string.
      // Since user-entered text may have unintentional HTML entities in it like
      // '<' or '>', we need to make sure these entities are properly escaped,
      // as the body will later be transformed from HTML to text, meaning
      // that a normal use of '<' will result in truncation of the message.
      $message['body'][] = check_plain($params['message']);
      break;
  }
}

/**
 * Sends an e-mail.
 *
 * @param array $message_values
 *   An array of values from the contact form fields that were submitted.
 *   There are just two relevant items: $message_values['to'] and
 *   $message_values['message'].
 */
function stockunlocks_mail_send($message_values) {
  // All system mails need to specify the module and template key (mirrored from
  // hook_mail()) that the message they want to send comes from.
  $module = 'stockunlocks';
  // $key = 'contact_message';
  $key = $message_values['key'];

  // Specify 'to' and 'from' addresses.
  $to = $message_values['to'];
  $from = $message_values['from'];

  // "params" loads in additional context for email content completion in
  // hook_mail(). In this case, we want to pass the values
  // which include the message body in $message_values['message'].
  $params = $message_values;
  $language = language_default();

  // Whether or not to automatically send the mail when drupal_mail() is
  // called. This defaults to TRUE, and is normally what you want unless you
  // need to do additional processing before drupal_mail_send() is called.
  $send = TRUE;
  // Send the mail, and check for success. Note that this does not guarantee
  // message delivery; only that there were no PHP-related issues encountered
  // while sending.
  $result = drupal_mail($module, $key, $to, $language, $params, $from, $send);

  return $result['result'];
}

// Includes dynamically created files containing functions
// for specific service providers, essential for completing orders,
// See: api_dynamic/api_functions_template.txt for an example.
$dirpath = variable_get('file_private_path', conf_path() . '/files/private');
include $dirpath . '/stockunlocks_api_dynamic/api_functions.inc';

/**
 * Processes orders where order_status = 'su_ordered'.
 */
function stockunlocks_process_orders() {
  $result_orders_ordered = array();
  $result_orders_completed = array();
  $result_orders_completed = stockunlocks_fetch_orders_completed();
  $result_orders_ordered = stockunlocks_fetch_orders_ordered();
  $flag_su_product = TRUE;
  // Process completed orders first.
  if (empty($result_orders_completed) && $result_orders_completed == NULL) {
  }
  else {
    $flag_su_product = TRUE;
    $i = 0;
    foreach ($result_orders_completed as $record_order_completed) {
      $uc_orders_data_completed = array();
      $uc_orders_data_completed['order_id'] = $record_order_completed->order_id;
      $uc_orders_data_completed['uid'] = $record_order_completed->uid;
      $uc_orders_data_completed['order_status'] = $record_order_completed->order_status;
      $uc_orders_data_completed['order_total'] = $record_order_completed->order_total;
      $uc_orders_data_completed['product_count'] = $record_order_completed->product_count;
      $uc_orders_data_completed['delivery_first_name'] = $record_order_completed->billing_first_name;
      $uc_orders_data_completed['primary_email'] = $record_order_completed->primary_email;
      $uc_orders_data_completed['payment_method'] = $record_order_completed->payment_method;
      ++$i;
      // The uc_orders table contains customer specific data:
      // contact, billing info, etc.
      // There are individual entries in the uc_order_products table,
      // representing completed orders.
      // These product contain product details. Collect them for processing.
      $result_order_products_completed = array();
      $result_order_products_completed_arr = array();
      $result_order_products_completed = db_query("SELECT * FROM {uc_order_products} WHERE order_id = :order_id", array(':order_id' => $uc_orders_data_completed['order_id']));
      if (!empty($result_order_products_completed) && $result_order_products_completed != NULL) {
        $result_order_products_completed_arr[] = $result_order_products_completed;
      }
      // Process the collected Ubercart ordered products (uc_order_products).
      if (!empty($result_order_products_completed_arr) && $result_order_products_completed_arr != NULL) {
        // Extract the specific order values to add to messages.
        $flag_su_product = stockunlocks_extract_order_values($result_order_products_completed_arr, $uc_orders_data_completed);
      }
    }
  }

  if ($flag_su_product) {
    // Product(s) found.
  }
  else {
    // Product(s) not found.
  }
  // Process Ubercart unlocking services orders that have been submitted.
  // Check the status for a successful code or not.
  if (empty($result_orders_ordered) && $result_orders_ordered == NULL) {
  }
  else {
    // Set customer and admin comment details and send e-mail.
    stockunlocks_set_comments_send_mail($result_orders_ordered);
    return NULL;
  }
}

/**
 * Extracts the specific order values to add to messages.
 */
function stockunlocks_extract_order_values(&$result_order_products_completed_arr, &$uc_orders_data_completed) {
  $flag_su_product = TRUE;
  foreach ($result_order_products_completed_arr as $result) {
    foreach ($result as $record) {
      $product_values = array();
      $imeiarray = array();
      $product_values['sku'] = $record->model;
      $product_values['nid'] = $record->nid;
      $product_values['order_id'] = $record->order_id;
      $product_values['price'] = number_format($record->price, 2);
      $product_values['qty'] = $record->qty;
      $product_values['total_price'] = number_format(($product_values['qty'] * $product_values['price']), 2);

      $node = node_load($product_values['nid']);
      $object = entity_metadata_wrapper('node', $node);

      $title = $object->title->value();
      $product_values['title'] = $title;
      // Uunlocking service, proceed.
      if (!empty($node->su_api_id[LANGUAGE_NONE][0]) && $node->su_api_id[LANGUAGE_NONE][0] != NULL) {
        // Extract specific details of this stockunlocks product.
        stockunlocks_process_product_node($node, $product_values, $record, $uc_orders_data_completed);
      }
      else {
        $flag_su_product = FALSE;
      }
    }
  }
  return $flag_su_product;
}

/**
 * Extracts specific details of a stockunlocks product node.
 */
function stockunlocks_process_product_node(&$node, &$product_values, &$record, &$uc_orders_data_completed) {
  $checkout_values = array();
  $item = $node->su_api_id[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_api_id', $item);
  $product_values['api_id'] = $output['#markup'];
  $checkout_values['API_ID'] = $product_values['api_id'];

  $item = $node->su_api_provider[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_api_provider', $item);
  $product_values['api_provider'] = $output['#markup'];

  $product_values['apiprovider_name'] = db_query('SELECT sitename FROM {su_api_provider} WHERE ID = :ID', array(':ID' => $product_values['api_provider']))->fetchField();

  $product_values['timestrict'] = 'inactive';
  $product_values['timestrictvalue'] = '0';
  if (!empty($node->su_time_strict[LANGUAGE_NONE][0]) && $node->su_time_strict[LANGUAGE_NONE][0] != NULL) {
    $item = $node->su_time_strict[LANGUAGE_NONE][0];
    $output = field_view_value('node', $node, 'su_time_strict', $item);
    $product_values['timestrict'] = $output['#markup'];
    $item = $node->su_time_strict_value[LANGUAGE_NONE][0];
    $output = field_view_value('node', $node, 'su_time_strict_value', $item);
    $product_values['timestrictvalue'] = $output['#markup'];
  }

  $product_values['processtime'] = '0';
  if (!empty($node->su_process_time[LANGUAGE_NONE][0]) && $node->su_process_time[LANGUAGE_NONE][0] != NULL) {
    $item = $node->su_process_time[LANGUAGE_NONE][0];
    $output = field_view_value('node', $node, 'su_process_time', $item);
    $product_values['processtime'] = $output['#markup'];
  }

  $item = $node->su_is_mep[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_mep', $item);
  $product_values['ismep'] = $output['#markup'];

  $item = $node->su_is_network[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_network', $item);
  $product_values['isnetwork'] = $output['#markup'];

  $item = $node->su_is_model[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_model', $item);
  $product_values['ismodel'] = $output['#markup'];

  $item = $node->su_is_pin[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_pin', $item);
  $product_values['ispin'] = $output['#markup'];

  $item = $node->su_is_rm_type[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_rm_type', $item);
  $product_values['isrmtype'] = $output['#markup'];

  $item = $node->su_is_kbh[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_kbh', $item);
  $product_values['iskbh'] = $output['#markup'];

  $item = $node->su_is_reference[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_reference', $item);
  $product_values['isreference'] = $output['#markup'];

  $item = $node->su_is_activation[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_activation', $item);
  $product_values['isactivation'] = $output['#markup'];

  $item = $node->su_is_service_tag[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_is_service_tag', $item);
  $product_values['isservicetag'] = $output['#markup'];

  $item = $node->su_price_group_id[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_price_group_id', $item);
  $product_values['pricegroupid'] = $output['#markup'];

  $item = $node->su_price_group_name[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_price_group_name', $item);
  $product_values['pricegroupname'] = $output['#markup'];

  $item = $node->su_serial_length[LANGUAGE_NONE][0];
  $output = field_view_value('node', $node, 'su_serial_length', $item);
  $product_values['seriallength'] = $output['#markup'];

  // Extract the order details, how many IMEI were ordered.
  $nestedarray = unserialize($record->data);
  $iterator = new RecursiveIteratorIterator(new RecursiveArrayIterator($nestedarray), RecursiveIteratorIterator::SELF_FIRST);
  foreach ($iterator as $key => $val_it) {
    if ($key === 'attributes') {
      if (is_array($val_it)) {
        foreach ($val_it as $aid => $val) {
          switch ($aid) {
            case 'IMEI':
              if ($product_values['qty'] > 1) {
                $imeiarray_tmp = explode("\n", trim($val[0]));
                foreach ($imeiarray_tmp as $key => $value) {
                  $imeiarray[] = trim($value);
                }
              }
              else {
                $imeiarray[] = trim($val[0]);
              }
              break;

            case 'Country':
              $checkout_values['CountryID'] = $val[0];
              break;

            case 'Network Provider':
              $checkout_values['NetworkID'] = $val[0];
              break;

            case 'Brand':
              $checkout_values['BrandID'] = $val[0];
              break;

            case 'Model':
              $checkout_values['ModelID'] = $val[0];
              break;

            case 'MEP Name':
              $checkout_values['MEPID'] = $val[0];
              break;

            case 'Serial Number (ESN)':
              $checkout_values['KBH'] = $val[0];
              break;

            case 'Phone Number':
              $checkout_values['ActivationPhoneNumber'] = $val[0];
              break;

            case 'Response Email':
              $checkout_values['RespondEmail'] = $val[0];
              break;

            case 'Additional Notes':
              $checkout_values['Notes'] = '#' . $product_values['order_id'] . ': ' . $val[0];
              break;

          }
          // Populate by default.
          // To be used when this functionality is enabled.
          $checkout_values['PIN'] = '';
          $checkout_values['PRD'] = '';
          $checkout_values['TYPE'] = '';
          $checkout_values['REFERENCE'] = '';
          $checkout_values['LOCKS'] = '';
        }
      }
    }
  }

  $checkout_values['$Country'] = '';
  $checkout_values['$Network'] = '';
  $checkout_values['$Brand'] = '';
  $checkout_values['$Model'] = '';
  $checkout_values['$PhoneNumber'] = '';
  $checkout_values['$MEPID'] = '';
  $checkout_values['$kbh'] = '';

  // Gather additional order specifics for messages and tracking.
  stockunlocks_set_order_values($checkout_values, $product_values);

  if (!empty($checkout_values['ActivationPhoneNumber']) && $checkout_values['ActivationPhoneNumber'] != NULL) {
    $checkout_values['$PhoneNumber'] = "\n" . 'Phone # : ' . $checkout_values['ActivationPhoneNumber'];
  }

  if (!empty($checkout_values['KBH']) && $checkout_values['KBH'] != NULL) {
    $checkout_values['$kbh'] = "\n" . 'KBH : ' . $checkout_values['KBH'];
  }

  $checkout_values['PhoneInfo'] = $checkout_values['$Country'] .
  $checkout_values['$Network'] . $checkout_values['$Brand'] .
  $checkout_values['$Model'] . $checkout_values['$PhoneNumber'] .
  $checkout_values['$MEPID'] . $checkout_values['$kbh'];
  // Submit the individual order(s). Retrieve the order id.
  foreach ($imeiarray as $item => $value) {
    $checkout_values['IMEI'] = $value;
    // Determine which Service Provider's API
    // to use for placing the order.
    $reply = array();
    $dirpath = variable_get('file_private_path', conf_path() . '/files/private');
    include $dirpath . '/stockunlocks_api_dynamic/api_switch_place_order.inc';
    if ($reply['RESULTS'] == 'SUCCESS') {
      // Build the email notification. Update the order status,
      // including the admin notes.
      $order_success_subject = '';
      $order_success_message = '';
      $order_success_fromname = '';
      $order_success_fromemail = '';
      $order_success_copyto = '';
      $results_order_success_admin = db_query('SELECT * FROM {su_emailtemplates} WHERE Name = :Name', array(':Name' => 'Order placed success notification'));
      if ($results_order_success_admin->rowCount() > 0) {
        foreach ($results_order_success_admin as $row) {
          $order_success_subject = $row->subject;
          $order_success_message = $row->message;
          $order_success_fromname = $row->fromname;
          $order_success_fromemail = $row->fromemail;
          $order_success_copyto = $row->copyto;
        }
        $replace = array(
          '{$imei}' => $checkout_values['IMEI'],
          '{$orderid}' => $product_values['order_id'],
        );
        $order_success_subject = stockunlocks_string_replace_assoc($replace, $order_success_subject);
        $replace = array(
          '{$customerfirstname}' => $uc_orders_data_completed['delivery_first_name'],
          '{$imei}' => $checkout_values['IMEI'],
          '{$orderid}' => $product_values['order_id'],
          '{$phoneinfo}' => $checkout_values['PhoneInfo'],
          '{$service}' => $product_values['title'],
        );
        $order_success_message = stockunlocks_string_replace_assoc($replace, $order_success_message);
      }
      $product_values['order_time'] = time();

      $comments_admin = 'su_ordered-php-' . $product_values['api_provider'] . '-php-' . $reply['REFERENCEID'] . '-php-' . $checkout_values['IMEI'] .
      '-php-' . $checkout_values['RespondEmail'] . '-php-' . $uc_orders_data_completed['delivery_first_name'] . '-php-' . $product_values['order_id'] .
      '-php-' . $product_values['title'] . '-php-' . $checkout_values['PhoneInfo'] . '-php-' . $product_values['order_time'] . '-php-' . $product_values['timestrict'] .
      '-php-' . $product_values['timestrictvalue'] . '-php-' . $uc_orders_data_completed['payment_method'] . '-php-' . $product_values['qty'] . '-php-' . $product_values['price'] . '-php-' . $product_values['total_price'] .
      '-php-' . $reply['RESULTS'] . '-php-' . $reply['MESSAGE'] . '-php-' . $reply['API_REPLY'] . '-php-' . $reply['API_CREDIT'] . '-php-' . $checkout_values['API_ID'];

      $emailsubject = $order_success_subject;
      $comments_order = $order_success_message;
      // Insert the admin comments into the table.
      $id = db_insert('uc_order_admin_comments')
      ->fields(array(
      'order_id' => $product_values['order_id'],
      'uid' => 1,
      'message' => $comments_admin,
      'created' => time(),
      ))
      ->execute();
      // Notify the customer regarding the order's status change.
      $body = $comments_order;
      $notified = 0;

      $message_values['key'] = 'contact_message';
      $message_values['from'] = $order_success_fromname . " <" . $order_success_fromemail . ">";
      $message_values['to'] = $checkout_values['RespondEmail'];
      $message_values['subject'] = $emailsubject;
      $message_values['message'] = $body;

      // If successful, send the admin a copy with debug info.
      if (stockunlocks_mail_send($message_values)) {
        $body = 'Customer email: ' . $checkout_values['RespondEmail'] . "\r\n" . $comments_order . "\r\n\r\n" . 'API Provider: ' . $product_values['apiprovider_name'] .
        "\r\n" . $reply['API_REPLY'] . "\r\n" . 'MSG RESULTS: ' . $reply['RESULTS'] . "\r\n" . 'MSG MESSAGE: ' . $reply['MESSAGE'] . "\r\n\r\n" . $comments_admin . "\r\n\r\n" .
        'table insert results: ' . $id;
        $emailsubject = 'cc: ' . $reply['RESULTS'] . ': ' . $emailsubject;
        $message_values['to'] = $order_success_copyto;
        $message_values['subject'] = $emailsubject;
        $message_values['message'] = $body;
        stockunlocks_mail_send($message_values);
        $notified = 1;
      }
      else {
        $notified = 0;
      }

      if ($notified == 1) {
        $id = db_insert('uc_order_comments')
        ->fields(array(
          'order_id' => $product_values['order_id'],
          'uid' => 1,
          'order_status' => 'su_ordered',
          'notified' => $notified,
          'message' => $comments_order,
          'created' => time(),
        ))
        ->execute();

        $id = db_update('uc_orders')
        ->fields(array('order_status' => 'su_ordered'))
        ->condition('order_id', $product_values['order_id'])
        ->execute();

      }
    }
    else {
      // Order processing failure. Notify admin of this error.
      $order_fail_subject = '';
      $order_fail_message = '';
      $order_fail_fromname = '';
      $order_fail_fromemail = '';
      $order_fail_copyto = '';
      $results_order_fail_admin = db_query('SELECT * FROM {su_emailtemplates} WHERE Name = :Name', array(':Name' => 'Order placed fail admin'));
      if ($results_order_fail_admin->rowCount() > 0) {
        foreach ($results_order_fail_admin as $row) {
          $order_fail_subject = $row->subject;
          $order_fail_message = $row->message;
          $order_fail_fromname = $row->fromname;
          $order_fail_fromemail = $row->fromemail;
          $order_fail_copyto = $row->copyto;
        }
        $replace = array(
          '{$imei}' => $checkout_values['IMEI'],
          '{$orderid}' => $product_values['order_id'],
        );
        $order_fail_subject = stockunlocks_string_replace_assoc($replace, $order_fail_subject);
        $replace = array(
          '{$apierrordesc}' => $reply['DESCRIPTION'],
          '{$apierrormsg}' => $reply['MESSAGE'],
          '{$customeremail}' => $checkout_values['RespondEmail'],
          '{$imei}' => $checkout_values['IMEI'],
          '{$orderid}' => $product_values['order_id'],
          '{$phoneinfo}' => $checkout_values['PhoneInfo'],
          '{$service}' => $product_values['title'],
        );
        $order_fail_message = stockunlocks_string_replace_assoc($replace, $order_fail_message);
      }

      $product_values['order_time'] = time();

      $comments_admin = 'su_order_error-php-' . $product_values['api_provider'] . '-php-' . $reply['DESCRIPTION'] . '-php-' . $checkout_values['IMEI'] .
      '-php-' . $checkout_values['RespondEmail'] . '-php-' . $uc_orders_data_completed['delivery_first_name'] . '-php-' . $product_values['order_id'] .
      '-php-' . $product_values['title'] . '-php-' . $checkout_values['PhoneInfo'] . '-php-' . $product_values['order_time'] . '-php-' . $product_values['timestrict'] .
      '-php-' . $product_values['timestrictvalue'] . '-php-' . $uc_orders_data_completed['payment_method'] . '-php-' . $product_values['qty'] . '-php-' . $product_values['price'] . '-php-' . $product_values['total_price'] .
      '-php-' . $reply['RESULTS'] . '-php-' . $reply['MESSAGE'] . '-php-' . $reply['API_REPLY'] . '-php-' . $checkout_values['API_ID'];

      $result_order_products_update = db_update('uc_orders')
      ->fields(array('order_status' => 'su_order_error'))
      ->condition('order_id', $product_values['order_id'])
      ->execute();

      // Insert the admin comments into
      // the uc_order_admin_comments table.
      $id = db_insert('uc_order_admin_comments')
      ->fields(array(
      'order_id' => $product_values['order_id'],
      'uid' => 1,
      'message' => $comments_admin,
      'created' => time(),
      ))
      ->execute();
      // Compose and send an email notification to admin.
      // NOTE: The customer still needs to be notified.
      // This is not yet automated.
      $emailsubject = $order_fail_subject;
      $comments_order = $order_fail_message;

      $body = $comments_order . "\r\n\r\n" . 'API Provider: ' . $product_values['api_provider'] . "\r\n" . $reply['API_REPLY'] . "\r\n" . 'MSG RESULTS: ' . $reply['RESULTS'] . "\r\n" . 'MSG MESSAGE: ' . $reply['MESSAGE'] . "\r\n\r\n" . $comments_admin;
      $notified = 0;

      $message_values['key'] = 'contact_message';
      $message_values['from'] = $order_fail_fromname . " <" . $order_fail_fromemail . ">";
      $message_values['to'] = $order_fail_copyto;
      $message_values['subject'] = $emailsubject;
      $message_values['message'] = $body;

      if (stockunlocks_mail_send($message_values)) {
        $notified = 1;
      }
      else {
        $notified = 0;
      }
    }
  }
}

/**
 * Gather additional order specifics for messages and tracking.
 */
function stockunlocks_set_order_values(&$checkout_values, &$product_values) {

  // Retrieve the country name.
  if (!empty($checkout_values['CountryID']) && $checkout_values['CountryID'] != NULL) {
    $results_country = db_query('SELECT Name FROM {su_service_country} WHERE api = :api AND api_provider = :api_provider ',
                                array(
                                  ':api' => $checkout_values['CountryID'],
                                  ':api_provider' => $product_values['api_provider'],
                                ));
    if ($results_country->rowCount() > 0) {
      foreach ($results_country as $row) {
        $checkout_values['$Country'] = "\n" . 'Country : ' . $row->Name;
      }
    }
  }
  // Retrieve the network name.
  if (!empty($checkout_values['NetworkID']) && $checkout_values['NetworkID'] != NULL) {
    $results_network = db_query('SELECT Name FROM {su_service_network} WHERE api = :api AND api_provider = :api_provider ',
                                array(
                                  ':api' => $checkout_values['NetworkID'],
                                  ':api_provider' => $product_values['api_provider'],
                                ));
    if ($results_network->rowCount() > 0) {
      foreach ($results_network as $row) {
        $checkout_values['$Network'] = "\n" . 'Network : ' . $row->Name;
      }
    }
  }
  // Retrieve the brand name.
  if (!empty($checkout_values['BrandID']) && $checkout_values['BrandID'] != NULL) {
    $results_brand = db_query('SELECT Name FROM {su_service_brand} WHERE api = :api AND api_provider = :api_provider ',
                                array(
                                  ':api' => $checkout_values['BrandID'],
                                  ':api_provider' => $product_values['api_provider'],
                                ));
    if ($results_brand->rowCount() > 0) {
      foreach ($results_brand as $row) {
        $checkout_values['$Brand'] = "\n" . 'Brand : ' . $row->Name;
      }
    }
  }
  // Retrieve the model name.
  if (!empty($checkout_values['ModelID']) && $checkout_values['ModelID'] != NULL) {
    $results_model = db_query('SELECT Name FROM {su_service_model} WHERE api = :api AND api_provider = :api_provider ',
                                array(
                                  ':api' => $checkout_values['ModelID'],
                                  ':api_provider' => $product_values['api_provider'],
                                ));
    if ($results_model->rowCount() > 0) {
      foreach ($results_model as $row) {
        $checkout_values['$Model'] = "\n" . 'Model : ' . $row->Name;
      }
    }
  }
  // Retrieve the MEP name.
  if (!empty($checkout_values['MEPID']) && $checkout_values['MEPID'] != NULL) {
    $results_mep = db_query('SELECT Name FROM {su_mep} WHERE api = :api AND api_provider = :api_provider ',
                                array(
                                  ':api' => $checkout_values['MEPID'],
                                  ':api_provider' => $product_values['api_provider'],
                                ));
    if ($results_mep->rowCount() > 0) {
      foreach ($results_mep as $row) {
        $checkout_values['$MEPID'] = "\n" . 'MEP : ' . $row->Name;
      }
    }
  }
}

/**
 * Set comments for the customer and admin and send e-mails.
 */
function stockunlocks_set_comments_send_mail(&$result_orders_ordered) {
  $i = 0;
  $order_values = array();
  $apiprovider_name = '';
  foreach ($result_orders_ordered as $record_orders_ordered) {
    $order_values['order_id'] = $record_orders_ordered->order_id;
    $order_values['uid'] = $record_orders_ordered->uid;
    $order_values['order_status'] = $record_orders_ordered->order_status;
    $order_values['order_total'] = $record_orders_ordered->order_total;
    $order_values['qty'] = $record_orders_ordered->product_count;
    $order_values['primary_email'] = $record_orders_ordered->primary_email;
    ++$i;
    $result_admin_comments_arr = array();
    $result_admin_comments_arr[] = $result_admin_comments = db_query("SELECT * FROM {uc_order_admin_comments} WHERE order_id = :order_id", array(':order_id' => $order_values['order_id']));
    foreach ($result_admin_comments_arr as $result) {
      foreach ($result as $record) {
        $order_values['order_id'] = $record->order_id;
        $results = explode('-php-', $record->message);
        foreach ($results as $entry => $values) {
          // Extract the Ubercart order information.
          if ($values == 'su_ordered') {
            $order_values['api_provider'] = $results[1];
            $order_values['api_order_id'] = $results[2];
            $order_values['IMEI'] = $results[3];
            $order_values['RespondEmail'] = $results[4];
            $order_values['delivery_first_name'] = $results[5];
            $order_values['title'] = $results[7];
            $order_values['PhoneInfo'] = $results[8];
            $order_values['order_time'] = $results[9];
            $order_values['timestrict'] = $results[10];
            $order_values['timestrictvalue'] = $results[11];
            $order_values['payment_method'] = $results[12];
            $order_values['order_time_diff'] = time() - $order_values['order_time'];
            $order_values['order_time_hours'] = $order_values['order_time_diff'] / 3600;
            $flag_timechk = TRUE;
            $apiprovider_name = db_query('SELECT sitename FROM {su_api_provider} WHERE ID = :ID', array(':ID' => $order_values['api_provider']))->fetchField();
            $special_customers = array('email@address.com');
            $special_email = strtolower($order_values['RespondEmail']);
            if (in_array($special_email, $special_customers)) {
              $order_values['timestrict'] = 'inactive';
            }
            if ($order_values['timestrict'] == 'inactive') {
              // Values to be implemented.
            }
            if ($order_values['timestrict'] == 'active') {
              if ($order_values['order_time_hours'] < $order_values['timestrictvalue']) {
                $flag_timechk = FALSE;
              }
            }
            $reply = array();
            // If the time is o.k., then check the status of the order.
            if ($flag_timechk) {
              // Determine which Service Provider's API to use
              // for checking the status of existing orders.
              $dirpath = variable_get('file_private_path', conf_path() . '/files/private');
              include $dirpath . '/stockunlocks_api_dynamic/api_switch_check_order.inc';
              // Build the email notification and update order_status.
              // Include admin notes and notify admin of any errors.
              if (!empty($reply) && $reply != NULL) {
                // There are results from the remote api.
                $breaks = array("<br />", "<br>", "<br/>");
                switch ($reply['RESULTS']) {
                  case 'ERROR':
                    // Possible API connection issues, notify Admin.
                    $order_fail_subject = '';
                    $order_fail_message = '';
                    $order_fail_fromname = '';
                    $order_fail_fromemail = '';
                    $order_fail_copyto = '';
                    $results_order_fail_check = db_query('SELECT * FROM {su_emailtemplates} WHERE Name = :Name', array(':Name' => 'Check order failed admin'));
                    if ($results_order_fail_check->rowCount() > 0) {
                      foreach ($results_order_fail_check as $row) {
                        $order_fail_subject = $row->subject;
                        $order_fail_message = $row->message;
                        $order_fail_fromname = $row->fromname;
                        $order_fail_fromemail = $row->fromemail;
                        $order_fail_copyto = $row->copyto;
                      }
                      $replace = array(
                        '{$imei}' => $order_values['IMEI'],
                        '{$orderid}' => $order_values['order_id'],
                      );
                      $order_fail_subject = stockunlocks_string_replace_assoc($replace, $order_fail_subject);
                      $replace = array(
                        '{$apierrormsg}' => $reply['MESSAGE'],
                        '{$apierrorresults}' => $reply['RESULTS'],
                        '{$apiprovider}' => $apiprovider_name,
                        '{$imei}' => $order_values['IMEI'],
                        '{$orderid}' => $order_values['order_id'],
                        '{$phoneinfo}' => $order_values['PhoneInfo'],
                        '{$service}' => $order_values['title'],
                      );
                      $order_fail_message = stockunlocks_string_replace_assoc($replace, $order_fail_message);
                    }
                    $order_values['order_time'] = time();

                    $comments_admin = 'check_order_error-php-' . $order_values['api_provider'] . '-php-' . $order_values['IMEI'] . '-php-' . $order_values['RespondEmail'] .
                    '-php-' . $order_values['delivery_first_name'] . '-php-' . $order_values['order_id'] . '-php-' . $order_values['title'] . '-php-' . $order_values['PhoneInfo'] .
                    '-php-' . $order_values['order_time'] . '-php-' . $order_values['timestrict'] . '-php-' . $order_values['timestrictvalue'] . '-php-' . $order_values['payment_method'] .
                    '-php-' . $order_values['qty'] . '-php-' . $reply['RESULTS'] . '-php-' . $reply['MESSAGE'] . '-php-' . $order_values['api_order_id'];

                    // Insert the admin comments into the
                    // uc_order_admin_comments table.
                    $id = db_insert('uc_order_admin_comments')
                    ->fields(array(
                    'order_id' => $order_values['order_id'],
                    'uid' => 1,
                    'message' => $comments_admin,
                    'created' => time(),
                    ))
                    ->execute();
                    // Compose and send an email to admin.
                    $emailsubject = $order_fail_subject;
                    $comments_order = $order_fail_message;

                    $body = $comments_order;
                    $notified = 0;
                    $to = $order_fail_copyto;
                    $headers = "From: " . $order_fail_fromname . " <" . $order_fail_copyto . ">\r\n" . "X-Mailer: php";

                    $message_values['key'] = 'contact_message';
                    $message_values['from'] = $order_fail_fromname . " <" . $order_fail_copyto . ">";
                    $message_values['to'] = $order_fail_copyto;
                    $message_values['subject'] = $emailsubject;
                    $message_values['message'] = $body;

                    if (stockunlocks_mail_send($message_values)) {
                      $notified = 1;
                    }
                    else {
                      $notified = 0;
                    }

                    break;

                  case 'SUCCESS':
                    $order_status = '';
                    switch ($reply['STATUS']) {
                      case '0':
                        $order_status = 'Waiting Action';
                        break;

                      case '1':
                        $order_status = 'In Process';
                        break;

                      case '3':
                        $order_status = 'Rejected';
                        $order_reject_subject = '';
                        $order_reject_message = '';
                        $order_reject_fromname = '';
                        $order_reject_fromemail = '';
                        $order_reject_copyto = '';
                        $results_order_reject = db_query('SELECT * FROM {su_emailtemplates} WHERE Name = :Name', array(':Name' => 'Order rejected notification'));
                        if ($results_order_reject->rowCount() > 0) {
                          foreach ($results_order_reject as $row) {
                            $order_reject_subject = $row->subject;
                            $order_reject_message = $row->message;
                            $order_reject_fromname = $row->fromname;
                            $order_reject_fromemail = $row->fromemail;
                            $order_reject_copyto = $row->copyto;
                          }
                          $replace = array(
                            '{$imei}' => $order_values['IMEI'],
                            '{$orderid}' => $order_values['order_id'],
                          );
                          $order_reject_subject = stockunlocks_string_replace_assoc($replace, $order_reject_subject);
                          $replace = array(
                            '{$customerfirstname}' => $order_values['delivery_first_name'],
                            '{$imei}' => $order_values['IMEI'],
                            '{$orderid}' => $order_values['order_id'],
                            '{$reason}' => str_ireplace($breaks, "\r\n", $reply['CODE']),
                            '{$phoneinfo}' => $order_values['PhoneInfo'],
                            '{$service}' => $order_values['title'],
                          );
                          $order_reject_message = stockunlocks_string_replace_assoc($replace, $order_reject_message);
                        }
                        // Determine whether or not to flag for a refund.
                        $order_values['status'] = 'su_refund_pending';
                        switch ($order_values['payment_method']) {
                          case 'free_order':
                            $order_values['status'] = 'su_code_unavailable';
                            break;

                        }

                        $comments_admin = $order_values['status'] . '-php-' . $order_values['api_provider'] . '-php-' . $order_values['api_order_id'] . '-php-' . $order_values['IMEI'] .
                        '-php-' . $order_values['RespondEmail'] . '-php-' . $order_values['delivery_first_name'] . '-php-' . $order_values['order_id'] . '-php-' . $order_values['title'] .
                        '-php-' . $order_values['PhoneInfo'] . '-php-' . $order_values['payment_method'] . '-php-' . $order_values['qty'] . '-php-' . $reply['API_REPLY'] . '-php-' . $reply['API_CREDIT'];

                        // Insert the admin comments into the
                        // uc_order_admin_comments table.
                        // The uid of the admin = 1.
                        $id = db_insert('uc_order_admin_comments')
                        ->fields(array(
                        'order_id' => $order_values['order_id'],
                        'uid' => 1,
                        'message' => $comments_admin,
                        'created' => time(),
                        ))
                        ->execute();

                        $emailsubject = $order_reject_subject;
                        $comments_order = $order_reject_message;

                        $body = $comments_order;
                        $notified = 0;

                        $message_values['key'] = 'contact_message';
                        $message_values['from'] = $order_reject_fromname . " <" . $order_reject_fromemail . ">";
                        $message_values['to'] = $order_values['RespondEmail'];
                        $message_values['subject'] = $emailsubject;
                        $message_values['message'] = $body;

                        if (stockunlocks_mail_send($message_values)) {

                          $body = 'Customer email: ' . $order_values['RespondEmail'] . "\r\n" . $comments_order . "\r\n\r\n" . 'API Provider: ' . $apiprovider_name .
                          "\r\n" . $reply['API_REPLY'] . "\r\n" . 'MSG RESULTS: ' . $reply['RESULTS'] . "\r\n\r\n" . $comments_admin . "\r\n\r\n" .
                          'Order Status: ' . $order_status;

                          $emailsubject = 'cc: UNAVAILABLE: ' . $emailsubject;
                          // Send a copy of the message to Support.
                          $message_values['to'] = $order_reject_copyto;
                          $message_values['subject'] = $emailsubject;
                          $message_values['message'] = $body;
                          stockunlocks_mail_send($message_values);
                          $notified = 1;
                        }
                        else {
                          $notified = 0;
                        }

                        $id = db_insert('uc_order_comments')
                        ->fields(array(
                        'order_id' => $order_values['order_id'],
                        'uid' => 1,
                        'order_status' => $order_values['status'],
                        'notified' => $notified,
                        'message' => $comments_order,
                        'created' => time(),
                        ))
                        ->execute();
                        // "1" means that the customer
                        // has been notified via email.
                        if ($notified == 1) {
                          $order_values['comment_id'] = $record->comment_id;
                          $order_values['admin_msg'] = $record->message;
                          $order_values['admin_msg_new'] = str_replace('su_ordered-php-', 'processed-php-', $record->message);

                          $id = db_update('uc_order_admin_comments')
                          ->fields(array('message' => $order_values['admin_msg_new']))
                          ->condition('comment_id', $order_values['comment_id'])
                          ->execute();

                        }

                        break;

                      case '4':
                        $order_status = 'Success';
                        $order_avail_subject = '';
                        $order_avail_message = '';
                        $order_avail_fromname = '';
                        $order_avail_fromemail = '';
                        $order_avail_copyto = '';
                        $results_order_avail = db_query('SELECT * FROM {su_emailtemplates} WHERE Name = :Name', array(':Name' => 'Order available notification'));
                        if ($results_order_avail->rowCount() > 0) {
                          foreach ($results_order_avail as $row) {
                            $order_avail_subject = $row->subject;
                            $order_avail_message = $row->message;
                            $order_avail_fromname = $row->fromname;
                            $order_avail_fromemail = $row->fromemail;
                            $order_avail_copyto = $row->copyto;
                          }
                          $replace = array(
                            '{$imei}' => $order_values['IMEI'],
                            '{$orderid}' => $order_values['order_id'],
                          );
                          $order_avail_subject = stockunlocks_string_replace_assoc($replace, $order_avail_subject);
                          $replace = array(
                            '{$customerfirstname}' => $order_values['delivery_first_name'],
                            '{$imei}' => $order_values['IMEI'],
                            '{$orderid}' => $order_values['order_id'],
                            '{$reply}' => str_ireplace($breaks, "\r\n", $reply['CODE']),
                            '{$phoneinfo}' => $order_values['PhoneInfo'],
                            '{$service}' => $order_values['title'],
                          );
                          $order_avail_message = stockunlocks_string_replace_assoc($replace, $order_avail_message);
                        }

                        $order_values['status'] = 'su_code_available';

                        $comments_admin = 'su_code_available-php-' . $order_values['api_provider'] . '-php-' . $order_values['api_order_id'] . '-php-' .
                        $order_values['IMEI'] . '-php-' . $order_values['RespondEmail'] . '-php-' . $order_values['delivery_first_name'] . '-php-' . $order_values['order_id'] .
                        '-php-' . $order_values['title'] . '-php-' . $order_values['PhoneInfo'] . '-php-' . $order_values['payment_method'] . '-php-' . $order_values['qty'] .
                        '-php-' . $reply['API_REPLY'] . '-php-' . $apiprovider_name . '-php-' . $reply['API_CREDIT'];

                        $emailsubject = $order_avail_subject;
                        $comments_order = $order_avail_message;

                        // Insert the admin comments into
                        // the uc_order_admin_comments table.
                        $id = db_insert('uc_order_admin_comments')
                        ->fields(array(
                        'order_id' => $order_values['order_id'],
                        'uid' => 1,
                        'message' => $comments_admin,
                        'created' => time(),
                        ))
                        ->execute();

                        $body = $comments_order;
                        $notified = 0;
                        $to = $order_values['RespondEmail'];

                        $message_values['key'] = 'contact_message';
                        $message_values['from'] = $order_avail_fromname . " <" . $order_avail_fromemail . ">";
                        $message_values['to'] = $order_values['RespondEmail'];
                        $message_values['subject'] = $emailsubject;
                        $message_values['message'] = $body;

                        if (stockunlocks_mail_send($message_values)) {
                          $body = 'Customer email: ' . $order_values['RespondEmail'] . "\r\n" . $comments_order . "\r\n\r\n" . 'API Provider: ' . $apiprovider_name .
                          "\r\n" . $reply['API_REPLY'] . "\r\n" . 'MSG RESULTS: ' . $reply['RESULTS'] . "\r\n\r\n" . $comments_admin;
                          $emailsubject = 'cc: AVAILABLE: ' . $emailsubject;
                          // Send a copy of the message to Support.
                          $message_values['to'] = $order_avail_copyto;
                          $message_values['subject'] = $emailsubject;
                          $message_values['message'] = $body;
                          stockunlocks_mail_send($message_values);
                          $notified = 1;
                        }
                        else {
                          $notified = 0;
                        }

                        $id = db_insert('uc_order_comments')
                        ->fields(array(
                         'order_id' => $order_values['order_id'],
                         'uid' => 1,
                         'order_status' => $order_values['status'],
                         'notified' => $notified,
                         'message' => $comments_order,
                         'created' => time(),
                        ))
                        ->execute();

                        if ($notified == 1) {
                          $order_values['comment_id'] = $record->comment_id;
                          $order_values['admin_msg'] = $record->message;
                          $order_values['admin_msg_new'] = str_replace('su_ordered-php-', 'processed-php-', $record->message);

                          $result_admin_msg_update = db_update('uc_order_admin_comments')
                          ->fields(array('message' => $order_values['admin_msg_new']))
                          ->condition('comment_id', $order_values['comment_id'])
                          ->execute();

                        }
                        break;

                    }
                }

                if ($reply['RESULTS'] == 'SUCCESS') {
                  $result_admin_comments_arr_tmp = array();
                  $result_admin_comments_arr_tmp[] = db_query("SELECT * FROM {uc_order_admin_comments} WHERE order_id = :order_id", array(':order_id' => $order_values['order_id']));
                  $i_adcom = 0;
                  $flag_refund = FALSE;
                  foreach ($result_admin_comments_arr_tmp as $result) {
                    foreach ($result as $record) {
                      $order_values['order_id'] = $record->order_id;
                      $results = explode('-php-', $record->message);
                      foreach ($results as $entry => $values) {
                        if ($values == 'su_refund_pending') {
                          $flag_refund = TRUE;
                        }
                        // Extract the order information.
                        if ($values == 'processed') {
                          // Determine if this order has been filled or not.
                          // Find out how many have been processed and
                          // compare to the actual quantity ordered.
                          ++$i_adcom;
                        }
                      }
                    }
                  }
                  // If all IMEI are processed, then set the order_status
                  // to "su_code_available" or "su_refund_pending".
                  if (!empty($order_values['qty']) && $order_values['qty'] != NULL) {
                    if ($order_values['qty'] == $i_adcom) {
                      // There are no more pending IMEI to be processed.
                      // Update the order.
                      if ($flag_refund) {
                        $order_values['status'] = 'su_refund_pending';
                      }

                      $result_order_products_update = db_update('uc_orders')
                      ->fields(array('order_status' => $order_values['status']))
                      ->condition('order_id', $order_values['order_id'])
                      ->execute();

                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
