<?php

/**
 * @file
 * Alters the normal shopping cart/product presentation.
 */

include drupal_get_path('module', 'stockunlocks') . '/includes/stockunlocks.functions.cart.inc';

/**
 * Implements hook_form_alter().
 */
function stockunlocks_form_uc_cart_view_form_alter(&$form, &$form_state) {
  // Remove "update cart" button since updates must take place on product form.
  // Due to the nature of mobile unlocking services:
  // Each additional item must have a unique, associated IMEI number.
  // Simply incrementing up the qty will not suffice.
  // Need ability to edit the cart item directly, to add or remove items.
  unset($form['actions']['update']);

  $form['#after_build'][] = '_stockunlocks_uc_cart_view_form_after_build';
  if (count($form['items'])) {
    $form['items']['#columns']['remove'] = array(
      'cell'   => t('Remove'),
      'weight' => 0,
    );

    $form['items']['#columns']['qty'] = array(
      'cell'   => t('Qty'),
      'weight' => 3,
    );

    // Add an edit column to the tapir table.
    $form['items']['#columns']['Edit'] = array(
      'cell'   => t('Edit'),
      'weight' => 5,
    );

    // Add an edit link to all products.
    foreach (element_children($form['items']) as $key) {
      // Products will have a cart_item_id-element.
      // Other elements will either be line items or product kits.
      if (isset($form['items'][$key]['cart_item_id'])) {
        // Re-do the remove button.
        unset($form['items'][$key]['remove']);

        $ciid = $form['items'][$key]['cart_item_id']['#value'];

        $form['items'][$key]['remove'] = array(
          '#type' => 'image_button',
          '#title' => t('Remove'),
          '#name' => 'remove-' . $ciid,
          '#src' => drupal_get_path('module', 'stockunlocks') . '/images/su-misc-images/cart-delete.gif',
          '#default_value' => t('Remove') . ' -> ' . $key,
          "#executes_submit_callback" => TRUE,
        );
        // Mod the display of icon & description, disable link to the product.
        $form['items'][$key]['image'] = array(
          stockunlocks_product_get_picture($form['items'][$key]['nid']['#value'], 'uc_cart'),
        );

        $form['items'][$key]['desc'] = array(
          '#markup' => l(html_entity_decode(strip_tags($form['items'][$key]['title']['#markup'])), 'node/' . $form['items'][$key]['nid']['#value'],
            array('query' => array('ciid' => $form['items'][$key]['cart_item_id']['#value']))) . $form['items'][$key]['description']['#markup'],
        );

        $form['items'][$key]['qty'] = array(
          '#markup' => $form['items'][$key]['qty']['#default_value'],
        );

        // Add a simple edit link with an additional parameter attached.
        // No need to perform a POST request, since cart item id, will change.
        $form['items'][$key]['Edit'] = array(
          '#markup' => l(t('Edit'), 'node/' . $form['items'][$key]['nid']['#value'],
            array('query' => array('ciid' => $form['items'][$key]['cart_item_id']['#value']))),
        );
      }
    }

  }
  return $form;
}

/**
 * Implements hook_form_after_build().
 */
function _stockunlocks_uc_cart_view_form_after_build($form, &$form_state) {
  $form['#validate'][] = '_stockunlocks_uc_cart_view_form_validate';
  return $form;
}

/**
 * Implements hook_form_validate().
 */
function _stockunlocks_uc_cart_view_form_validate($form, &$form_state) {
  // The remove button was clicked.
  if (substr($form_state['triggering_element']['#name'], 0, 7) == 'remove-') {
    $ciid = substr($form_state['triggering_element']['#name'], 7);
    $value = substr($form_state['triggering_element']['#default_value'], 10);
    $nid = '';
    $data = '';
    $items = uc_cart_get_contents();
    foreach ($items as $item) {
      if ($item->cart_item_id == $ciid) {
        $nid = $item->nid;
        $data = $item->data;
        uc_cart_remove_item($nid, NULL, $data);
      }
    }
    // Placeholder: !product-title, Drupal previously filtered upon creation.
    drupal_set_message(t('<strong>!product-title</strong> removed from your shopping cart.', array('!product-title' => $form['items'][$value]['title']['#markup'])));
    drupal_goto('cart');
  }
}

/**
 * Implements hook_form_alter().
 */
function stockunlocks_form_alter(&$form, $form_state, $form_id) {
  // Disable the submit button once an order is submitted (via Actions page).
  if (strstr($form_id, 'api_')) {
    $form['api_action']['#after_build'] = array('stockunlocks_load_submit_disable_javascript');
  }
  // Only affect unlocking services, leave all the other products alone!
  if (!empty($form['attributes'][SU_AID_IMEI]) && $form['attributes'][SU_AID_IMEI] != NULL) {
    if (strstr($form_id, 'uc_product_add_to_cart_form')) {
      // Attach the CSS and JS we need to show this with/without javascript.
      // Without javascript we need an extra "Choose" button, and this is
      // hidden when we have javascript enabled.
      $form['#attached']['css'] = array(
        drupal_get_path('module', 'stockunlocks') . '/css/stockunlocks.css',
      );
      $form['#attached']['js'] = array(
        drupal_get_path('module', 'stockunlocks') . '/js/stockunlocks.js',
      );

      unset($form['qty']);
      $form['#after_build'][] = '_stockunlocks_after_build';

      $nid = $form['nid']['#value'];
      $node = node_load($nid);

      $selected_service = '';
      if (!empty($node->su_api_id[LANGUAGE_NONE][0]) && $node->su_api_id[LANGUAGE_NONE][0] != NULL) {
        $item = $node->su_api_id[LANGUAGE_NONE][0];
        $output = field_view_value('node', $node, 'su_api_id', $item);
        $selected_service = $output['#markup'];
      }

      $api_provider = '';
      if (!empty($node->su_api_provider[LANGUAGE_NONE][0]) && $node->su_api_provider[LANGUAGE_NONE][0] != NULL) {
        $item = $node->su_api_provider[LANGUAGE_NONE][0];
        $output = field_view_value('node', $node, 'su_api_provider', $item);
        $api_provider = $output['#markup'];
      }

      $assigned_brand = '';
      if (!empty($node->su_assigned_brand[LANGUAGE_NONE][0]) && $node->su_assigned_brand[LANGUAGE_NONE][0] != NULL) {
        $item = $node->su_assigned_brand[LANGUAGE_NONE][0];
        $output = field_view_value('node', $node, 'su_assigned_brand', $item);
        $assigned_brand = $output['#markup'];
      }

      $assigned_model = '';
      if (!empty($node->su_assigned_model[LANGUAGE_NONE][0]) && $node->su_assigned_model[LANGUAGE_NONE][0] != NULL) {
        $item = $node->su_assigned_model[LANGUAGE_NONE][0];
        $output = field_view_value('node', $node, 'su_assigned_model', $item);
        $assigned_model = $output['#markup'];
      }

      $assigned_provider = '';
      if (!empty($node->su_assigned_network_provider[LANGUAGE_NONE][0]) && $node->su_assigned_network_provider[LANGUAGE_NONE][0] != NULL) {
        $item = $node->su_assigned_network_provider[LANGUAGE_NONE][0];
        $output = field_view_value('node', $node, 'su_assigned_network_provider', $item);
        $assigned_provider = $output['#markup'];
      }

      $process_time = '';
      if (!empty($node->su_process_time[LANGUAGE_NONE][0]) && $node->su_process_time[LANGUAGE_NONE][0] != NULL) {
        $item = $node->su_process_time[LANGUAGE_NONE][0];
        $output = field_view_value('node', $node, 'su_process_time', $item);
        $process_time = $output['#markup'];
      }

      $tmp_status = '';
      $tmp_disabled = FALSE;
      if (!empty($node->su_temp_status[LANGUAGE_NONE][0]) && $node->su_temp_status[LANGUAGE_NONE][0] != NULL) {
        $item = $node->su_temp_status[LANGUAGE_NONE][0];
        $output = field_view_value('node', $node, 'su_temp_status', $item);
        $tmp_status = $output['#markup'];
        if ($tmp_status != 'online') {
          $tmp_disabled = TRUE;
        }
      }

      $item = $node->su_is_mep[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_mep', $item);
      $is_mep = $output['#markup'];

      $item = $node->su_is_network[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_network', $item);
      $is_network = $output['#markup'];

      $item = $node->su_is_model[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_model', $item);
      $is_model = $output['#markup'];

      $item = $node->su_is_pin[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_pin', $item);
      $is_pin = $output['#markup'];

      $item = $node->su_is_rm_type[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_rm_type', $item);
      $is_rm_type = $output['#markup'];

      $item = $node->su_is_kbh[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_kbh', $item);
      $is_kbh = $output['#markup'];

      $item = $node->su_is_reference[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_reference', $item);
      $is_reference = $output['#markup'];

      $item = $node->su_is_service_tag[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_service_tag', $item);
      $is_service_tag = $output['#markup'];

      $item = $node->su_is_activation[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_is_activation', $item);
      $is_activation = $output['#markup'];

      $item = $node->su_price_group_id[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_price_group_id', $item);
      $price_group_id = $output['#markup'];

      $item = $node->su_price_group_name[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_price_group_name', $item);
      $price_group_name = $output['#markup'];

      $item = $node->su_serial_length[LANGUAGE_NONE][0];
      $output = field_view_value('node', $node, 'su_serial_length', $item);
      $serial_length = $output['#markup'];
      // Cart ID is needed for access validation if editing an existing entry.
      $user_cart_id = uc_cart_get_id();
      $adminemail = db_query('SELECT fromemail FROM {su_emailtemplates} WHERE Name = :Name', array(':Name' => 'Order available notification'))->fetchField();

      // Hide all fields by default.
      $dropdown_display_country = FALSE;
      $dropdown_display_network = FALSE;
      $dropdown_display_brand = FALSE;
      $dropdown_display_model = FALSE;
      $display_kbh_esn = FALSE;
      $display_activation_phone = FALSE;
      $dropdown_display_mep = FALSE;
      $flag_edit = FALSE;

      $tmp_option_values = '';
      $cart_item_id_ck = '';
      $cart_item_id = '';
      $cart_nid = '';
      $qty_orig = '0';
      $cart_data = '';
      $cart_data_attributes_only = '';
      $options_country = array();
      $selected_country = '';
      $country_item_id = '';
      $options_network = array();
      $selected_network = '';
      $network_item_id = '';
      $options_brand = array();
      $selected_brand = '';
      $brand_item_id = '';
      $options_model = array();
      $selected_model = '';
      $model_item_id = '';
      $options_mep  = array();
      $selected_mep = '';
      $selected_imei = '';
      $selected_kbh_esn = '';
      $selected_activation_phone = '';
      $selected_email_response = '';
      $selected_email_confirm = '';
      $selected_notes = '';
      $icon_path_model = drupal_get_path('module', 'stockunlocks') . '/su-service-images/imei.gif';

      if (!empty($GLOBALS['user']->mail) && $GLOBALS['user']->mail != NULL) {
        $selected_email_response = $GLOBALS['user']->mail;
        $selected_email_confirm = $GLOBALS['user']->mail;
      }

      if (isset($_GET['ciid']) || !empty($_SESSION['$stockunlocks_$session_$cart_item_id'])) {
        // Extract cart item id from url or retrieve it from the session.
        if (isset($_GET['ciid'])) {
          $cart_item_id = $_GET['ciid'];
          $_SESSION['$stockunlocks_$session_$cart_item_id'] = $cart_item_id;
          // 0 = coming from home page with criteria, not yet in the cart.
          if ($cart_item_id != 'x') {
            $flag_edit = TRUE;
          }
        }
        else {
          $cart_item_id = $_SESSION['$stockunlocks_$session_$cart_item_id'];
        }

        if (isset($_GET['biid'])) {
          $brand_item_id = $_GET['biid'];
          $selected_brand = $brand_item_id;
        }
        if (isset($_GET['miid'])) {
          $model_item_id = $_GET['miid'];
          $selected_model = $model_item_id;
        }
        if (isset($_GET['tiid'])) {
          $country_item_id = $_GET['tiid'];
          $selected_country = $country_item_id;
        }
        if (isset($_GET['niid'])) {
          $network_item_id = $_GET['niid'];
          $selected_network = $network_item_id;
        }
        // Load cart item from the database.
        // Get the cart id related to this entry.
        $result = db_query("SELECT nid, cart_id, qty, cart_item_id, data  FROM {uc_cart_products} WHERE cart_item_id = :cart_item_id", array(':cart_item_id' => $cart_item_id));
        foreach ($result as $item) {
          $cart_item_id_ck = $item->cart_id;
          $cart_item_id = $item->cart_item_id;
          $cart_nid = $item->nid;
          $qty_orig = $item->qty;
          $cart_data = $item->data;
        }
        // Check if item CLICKED IN VIEW is part of the active user's cart.
        if ($cart_item_id_ck === $user_cart_id) {
          $tmp_option_values = $cart_data;
          // Initialize empty array for serialized data.
          $nestedarray = array();
          // We should now have the serialized data in $nestedarray.
          $nestedarray = unserialize($tmp_option_values);
          if (!is_array($nestedarray)) {
            // Something went wrong, re-initialize to empty array.
            $nestedarray = array();
          }
          // Extract Ubercart attributes for comparison before removal.
          $cart_data_attributes_only = serialize($nestedarray['attributes']);
          $iterator = new RecursiveIteratorIterator(new RecursiveArrayIterator($nestedarray), RecursiveIteratorIterator::SELF_FIRST);
          foreach ($iterator as $key => $val_it) {
            if ($key === 'attributes') {
              if (is_array($val_it)) {
                foreach ($val_it as $aid => $val) {
                  switch ($aid) {
                    case SU_AID_COUNTRY:
                      $selected_country = $val;
                      break;

                    case SU_AID_NETWORK:
                      $selected_network = $val;
                      break;

                    case SU_AID_BRAND:
                      $selected_brand = $val;
                      break;

                    case SU_AID_MODEL:
                      $selected_model = $val;
                      break;

                    case SU_AID_MEP:
                      $selected_mep = $val;
                      break;

                    case SU_AID_IMEI:
                      $selected_imei = $val;
                      break;

                    case SU_AID_EMAIL_RESPONSE:
                      $selected_email_response = $val;
                      break;

                    case SU_AID_NOTES:
                      $selected_notes = $val;
                      break;

                    case SU_AID_EMAIL_CONFIRM:
                      $selected_email_confirm = $val;
                      break;

                    case SU_AID_PHONE_NUM:
                      $selected_activation_phone = $val;
                      break;

                    case SU_AID_KBH:
                      $selected_kbh_esn = $val;
                      break;

                  }
                }
              }
            }
          }
        }
      }

      $form['$ProcessTime'] = array(
        '#type' => 'hidden',
        '#value' => $process_time,
      );

      $form['$tmp_status'] = array(
        '#type' => 'hidden',
        '#value' => $tmp_status,
      );

      $form['$IsMEP'] = array(
        '#type' => 'hidden',
        '#value' => $is_mep,
      );

      $form['$IsNetwork'] = array(
        '#type' => 'hidden',
        '#value' => $is_network,
      );

      $form['$IsModel'] = array(
        '#type' => 'hidden',
        '#value' => $is_model,
      );

      $form['$IsActivation'] = array(
        '#type' => 'hidden',
        '#value' => $is_activation,
      );

      $form['$IsPin'] = array(
        '#type' => 'hidden',
        '#value' => $is_pin,
      );

      $form['$IsRMType'] = array(
        '#type' => 'hidden',
        '#value' => $is_rm_type,
      );

      $form['$IsKBH'] = array(
        '#type' => 'hidden',
        '#value' => $is_kbh,
      );

      $form['$IsReference'] = array(
        '#type' => 'hidden',
        '#value' => $is_reference,
      );

      $form['$IsServiceTag'] = array(
        '#type' => 'hidden',
        '#value' => $is_service_tag,
      );

      $form['$PriceGroupID'] = array(
        '#type' => 'hidden',
        '#value' => $price_group_id,
      );

      $form['$PriceGroupName'] = array(
        '#type' => 'hidden',
        '#value' => $price_group_name,
      );

      $form['$SerialLength'] = array(
        '#type' => 'hidden',
        '#value' => $serial_length,
      );

      $form['qty'] = array(
        '#type' => 'hidden',
        '#value' => '0',
      );

      $form['cart_item_id'] = array(
        '#type' => 'hidden',
        '#value' => $cart_item_id,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('cart-item-id'),
        ),
      );

      $form['cart_id'] = array(
        '#type' => 'hidden',
        '#value' => '',
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('cart-id'),
        ),
      );

      $form['current_nid'] = array(
        '#type' => 'hidden',
        '#value' => $nid,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('current-nid'),
        ),
      );

      $form['cart_nid'] = array(
        '#type' => 'hidden',
        '#value' => $cart_nid,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('cart-nid'),
        ),
      );

      $form['qty_orig'] = array(
        '#type' => 'hidden',
        '#value' => $qty_orig,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('qty-orig'),
        ),
      );

      $form['cart_data_attributes_only'] = array(
        '#type' => 'hidden',
        '#value' => $cart_data_attributes_only,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('cart-data-attributes-only'),
        ),
      );

      $form['cart_data'] = array(
        '#type' => 'hidden',
        '#value' => $cart_data,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('cart-data'),
        ),
      );

      $form['service_id'] = array(
        '#type' => 'hidden',
        '#value' => $selected_service,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('service-id'),
        ),
      );

      $form['brand_item_id'] = array(
        '#type' => 'hidden',
        '#value' => $brand_item_id,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('service-id'),
        ),
      );

      $form['model_item_id'] = array(
        '#type' => 'hidden',
        '#value' => $model_item_id,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('service-id'),
        ),
      );

      $form['network_item_id'] = array(
        '#type' => 'hidden',
        '#value' => $network_item_id,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('service-id'),
        ),
      );

      $form['country_item_id'] = array(
        '#type' => 'hidden',
        '#value' => $country_item_id,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('service-id'),
        ),
      );

      if ($is_network == '1') {
        $dropdown_display_network = TRUE;
        $options_country_chk = stockunlocks_cart_fetch_country($assigned_provider, $api_provider);
        $options_country_count = count($options_country_chk);

        if ($options_country_count == 1) {
          // No selections to choose from.
          $options_country = $options_country_chk;
          // Don't display, there's nothing to choose from.
          $dropdown_display_country = FALSE;
        }

        if ($options_country_count == 2) {
          // Don't display, there's only one choice. Set to this single value.
          $dropdown_display_country = FALSE;
          $_i = 0;
          foreach ($options_country_chk as $record => $value) {
            // Skip the first value, it's NULL.
            if ($_i == 1) {
              $options_country[$record] = $value;
              $selected_country = $record;
            }
            ++$_i;
          }
        }

        if ($options_country_count > 2) {
          $options_country = $options_country_chk;
          // Display the values, there are multiple choices.
          $dropdown_display_country = TRUE;
        }
      }

      $suffix_country = 'Country <font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_COUNTRY] = array(
        '#type' => 'select',
        '#field_suffix' => $suffix_country,
        '#access' => $dropdown_display_country,
        '#weight' => -50,
        '#prefix' => '<div id="dropdown-country-replace">',
        '#suffix' => '</div>',
        // This prevents the illegal choice selection problem.
        '#validated' => TRUE,
        '#attributes' => array('class' => array('enabled-for-ajax')),
        // The '#ajax' property allows us to bind a callback to the server
        // whenever this form element changes.
        '#ajax' => array(
          'callback' => 'stockunlocks_ajax_dropdown_country_callback',
          'wrapper' => "dropdown-network-replace",
          'effect' => 'fade',
        ),
        '#options' => $options_country,
        // When the form is rebuilt during processing, either AJAX or multistep,
        // the $selected variable will now have the new value and so the options
        // will change.
        '#default_value' => $selected_country,
      );
      // Since we don't know if the user has js or not, we always need to output
      // this element, then hide it with css if javascript is enabled.
      $form['attributes']['continue_to_network'] = array(
        '#access' => $dropdown_display_country,
        '#weight' => -49,
        '#type' => 'submit',
        '#value' => t('Choose Country'),
        '#attributes' => array('class' => array('stockunlocks-cart-next-button')),
      );

      $form['display_country'] = array(
        '#type' => 'hidden',
        '#value' => $dropdown_display_country,
        '#attributes' => array(
          'class' => array('enabled-for-ajax'),
          'id' => array('display-country'),
        ),
      );

      if (!empty($form_state['values']['attributes'][SU_AID_COUNTRY])) {
        $selected_country = $form_state['values']['attributes'][SU_AID_COUNTRY];
      }
      $options_network_chk = stockunlocks_cart_fetch_network($assigned_provider, $selected_country, $api_provider);
      $network_options_count = count($options_network_chk);
      // If there is only one network, then set that as the only value.
      if ($network_options_count == 1) {
        $options_network = $options_network_chk;
      }
      if ($network_options_count == 2) {
        // Don't display, there's only one choice. Set to this single value.
        $_i = 0;
        foreach ($options_network_chk as $record => $value) {
          if ($_i == 1) {
            $options_network[$record] = $value;
            $selected_network = $record;
          }
          ++$_i;
        }
      }
      if ($network_options_count > 2) {
        $options_network = $options_network_chk;
      }

      $suffix_network = 'Network Provider <font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_NETWORK] = array(
        '#type' => 'select',
        '#field_suffix' => $suffix_network,
        '#access' => $dropdown_display_network,
        '#weight' => -45,
        '#prefix' => '<div id="dropdown-network-replace">',
        '#suffix' => '</div>',
        // This prevents the illegal choice selection problem.
        '#validated' => TRUE,
        '#attributes' => array('class' => array('enabled-for-ajax')),
        // The '#ajax' property allows us to bind a callback to the server
        // whenever this form element changes.
        '#ajax' => array(
          'callback' => 'stockunlocks_ajax_dropdown_network_callback',
          'wrapper' => 'dropdown-blank-replace',
          'effect' => 'fade',
        ),
        '#options' => $options_network,
        // When the form is rebuilt during processing ( AJAX or multistep),
        // the $selected variable will now have the new value so the options
        // will change.
        '#default_value' => $selected_network,
      );
      // Since we don't know if user has js or not, we always need to output
      // this element, then hide it with with css if javascript is enabled.
      $form['attributes']['continue_to_brand'] = array(
        '#access' => $dropdown_display_network,
        '#weight' => -44,
        '#type' => 'submit',
        '#value' => t('Choose Network'),
        '#attributes' => array('class' => array('stockunlocks-cart-next-button')),
      );

      $form['display_network'] = array(
        '#type' => 'hidden',
        '#value' => $dropdown_display_network,
      );

      if ($is_model == '1') {
        $dropdown_display_model = TRUE;
        $options_brand_chk = stockunlocks_cart_fetch_brand($assigned_brand, $api_provider);
        $brand_options_count = count($options_brand_chk);

        // If there is only one brand, then set that as the only value.
        if ($brand_options_count == 1) {
          $options_brand = $options_brand_chk;
          $dropdown_display_brand = FALSE;
        }
        // Don't display, there's only one choice. Set to this single value.
        if ($brand_options_count == 2) {
          $dropdown_display_brand = FALSE;
          $_i = 0;
          foreach ($options_brand_chk as $record => $value) {
            if ($_i == 1) {
              $options_brand[$record] = $value;
              $selected_brand = $record;
            }
            ++$_i;
          }
        }
        if ($brand_options_count > 2) {
          $options_brand = $options_brand_chk;
          // Display the values, there are multiple choices.
          $dropdown_display_brand = TRUE;
        }
      }

      $suffix_brand = 'Brand <font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_BRAND] = array(
        '#type' => 'select',
        '#field_suffix' => $suffix_brand,
        '#weight' => -40,
        // This prevents the illegal choice selection problem.
        '#validated' => TRUE,
        '#access' => $dropdown_display_brand,
        '#prefix' => '<div id="dropdown-brand-replace">',
        '#suffix' => '</div>',
        '#attributes' => array('class' => array('enabled-for-ajax')),
        // The '#ajax' property allows to bind a callback to the server
        // whenever this form element changes.
        '#ajax' => array(
          'callback' => 'stockunlocks_ajax_dropdown_brand_callback',
          'wrapper' => 'dropdown-model-replace',
          'effect' => 'fade',
        ),
        // When form is rebuilt during processing, either AJAX or multistep,
        // the $selected variable will now have the new value and so options
        // will change.
        '#options' => $options_brand,
        '#default_value' => $selected_brand,
      );
      // Since we don't know if the user has js or not, always need to output
      // this element, then hide it with with css if javascript is enabled.
      $form['attributes']['continue_to_model'] = array(
        '#access' => $dropdown_display_brand,
        '#weight' => -39,
        '#type' => 'submit',
        '#value' => t('Choose Brand'),
        '#attributes' => array('class' => array('stockunlocks-cart-next-button')),
      );

      $form['display_brand'] = array(
        '#type' => 'hidden',
        '#value' => $dropdown_display_brand,
      );

      $form['selected_brand'] = array(
        '#type' => 'hidden',
        '#value' => $selected_brand,
      );

      if (!empty($form_state['values']['attributes'][SU_AID_BRAND])) {
        $selected_brand = $form_state['values']['attributes'][SU_AID_BRAND];
      }
      $options_model = stockunlocks_cart_fetch_model($assigned_model, $selected_brand, $api_provider);
      $suffix_model = 'Model <font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_MODEL] = array(
        '#type' => 'select',
        '#field_suffix' => $suffix_model,
        '#weight' => -35,
        // This prevents the illegal choice selection problem.
        '#validated' => TRUE,
        '#access' => $dropdown_display_model,
        '#prefix' => '<div id="dropdown-model-replace">',
        '#suffix' => '</div>',
        '#attributes' => array('class' => array('enabled-for-ajax')),
        // The '#ajax' property allows to bind a callback to the server whenever
        // this form element changes.
        '#ajax' => array(
          'callback' => 'stockunlocks_ajax_dropdown_model_callback',
          'wrapper' => 'dropdown-mep-replace',
          'effect' => 'fade',
        ),
        // When the form is rebuilt during processing, either AJAX or multistep,
        // the $selected variable will now have the new value and so the options
        // will change.
        '#options' => $options_model,
        '#default_value' => $selected_model,
      );
      // Since we don't know if the user has js or not, we always need to output
      // this element, then hide it with with css if javascript is enabled.
      $form['attributes']['continue_to_icon'] = array(
        '#access' => $dropdown_display_model,
        '#weight' => -34,
        '#type' => 'submit',
        '#value' => t('Choose Model'),
        '#attributes' => array('class' => array('stockunlocks-cart-next-button')),
      );

      $form['display_model'] = array(
        '#type' => 'hidden',
        '#value' => $dropdown_display_model,
      );

      if (!empty($form_state['values']['attributes'][SU_AID_MODEL]) && $form_state['values']['attributes'][SU_AID_MODEL] != '') {
        $icon_path_model  = drupal_get_path('module', 'stockunlocks') . '/images/su-model-images/' .
        $options_model[$form_state['values']['attributes'][SU_AID_MODEL]] . '.jpg';
        if (!file_exists($icon_path_model)) {
          $icon_path_model  = drupal_get_path('module', 'stockunlocks') . '/images/su-service-images/imei.gif';
        }
      }
      else {
        $icon_path_model  = drupal_get_path('module', 'stockunlocks') . '/images/su-service-images/imei.gif';
      }

      $form['icon_model'] = array(
        '#type' => 'image_button',
        '#src' => $icon_path_model,
        '#name' => t('icon_model'),
        '#prefix' => '<div id="details-model-icon">',
        '#suffix' => '</div>',
        '#weight' => -30,
        "#executes_submit_callback" => FALSE,
        '#attributes' => array('class' => array('enabled-for-ajax')),
        '#ajax' => array(
          'callback' => 'stockunlocks_ajax_icon_model_callback',
          'wrapper' => 'stockunlocks-dropdown-model-replace',
          'effect' => 'fade',
        ),
      );

      $field_suffix = '';
      if ($is_mep == '1') {
        $options_mep = stockunlocks_cart_fetch_mep($api_provider);
        $dropdown_display_mep = TRUE;
        $field_suffix = t('MEP Name <font color="red"><b>*</b></font>');
      }
      else {
        $field_suffix = t('MEP Name (optional)');
      }
      $form['attributes'][SU_AID_MEP] = array(
        '#type' => 'select',
        '#field_suffix' => $field_suffix,
        // This prevents the illegal choice selection problem.
        '#validated' => TRUE,
        '#access' => $dropdown_display_mep,
        '#weight' => -25,
        '#prefix' => '<div id="dropdown-mep-replace">',
        '#suffix' => '</div>',
        '#attributes' => array('class' => array('enabled-for-ajax')),
        // The '#ajax' property allows us to bind a callback to the server
        // whenever this form element changes.
        '#ajax' => array(
          'callback' => 'stockunlocks_ajax_dropdown_mep_callback',
          'wrapper' => 'dropdown-brand-replace',
          'effect' => 'fade',
        ),
        // When the form is rebuilt during processing (AJAX or multistep),
        // the $selected variable will now have the new value and so the options
        // will change.
        '#options' => $options_mep,
        '#default_value' => $selected_mep,
      );
      // Since we don't know if the user has js or not, we always need to output
      // this element, then hide it with with css if javascript is enabled.
      $form['attributes']['continue_to_mep'] = array(
        '#access' => $dropdown_display_mep,
        '#weight' => -24,
        '#type' => 'submit',
        '#value' => t('Choose MEP'),
        '#attributes' => array('class' => array('stockunlocks-cart-next-button')),
      );

      $form['attributes'][SU_AID_IMEI] = array(
        '#field_prefix' => '<b>' . t('IMEI (Enter @var digits), dial *#06# to display: <br />Bulk Submit: One Per Line <font color="red"><b>*</b></font></b>', array('@var' => $serial_length)),
        '#type' => 'textarea',
        '#weight' => -20,
        '#default_value' => $selected_imei,
      );

      if ($is_kbh == '1') {
        $display_kbh_esn = TRUE;
      }

      $suffix_kbh_esn = '<font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_KBH] = array(
        '#title' => t("KBH/KRH/ESN (also known as serial number):"),
        '#field_suffix' => $suffix_kbh_esn,
        '#access' => $display_kbh_esn,
        '#type' => 'textfield',
        '#weight' => -18,
        '#default_value' => $selected_kbh_esn,
        '#description' => "<div id='kbh_esn_div'></div>",
      );

      if ($is_activation == '1') {
        $display_activation_phone = TRUE;
      }

      $suffix_activation_phone = '<font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_PHONE_NUM] = array(
        '#title' => t("Phone Number (Usually will show up in iTunes):"),
        '#field_suffix' => $suffix_activation_phone,
        '#access' => $display_activation_phone,
        '#type' => 'textfield',
        '#weight' => -17,
        '#default_value' => $selected_activation_phone,
        '#description' => "<div id='activation_phone_div'></div>",
      );

      // $adminemail filetered with filter_xss() in info_emailordersuccess.inc.
      $suffix_response_email = '<font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_EMAIL_RESPONSE] = array(
        '#title' => t('Response Email: (Add @var to your address book!)', array('@var' => $adminemail)),
        '#field_suffix' => $suffix_response_email,
        '#type' => 'textfield',
        '#weight' => -15,
        '#default_value' => $selected_email_response,
        '#description' => "<div id='email_response_div'></div>",
      );

      $suffix_confirm_email = '<font color="red"><b>*</b></font>';
      $form['attributes'][SU_AID_EMAIL_CONFIRM] = array(
        '#title' => t("Confirm Email:"),
        '#field_suffix' => $suffix_confirm_email,
        '#type' => 'textfield',
        '#weight' => -10,
        '#default_value' => $selected_email_confirm,
        '#description' => "<div id='email_confirm_div'></div>",
      );

      $form['attributes'][SU_AID_NOTES] = array(
        '#title' => t("Additional Notes:"),
        '#type' => 'textfield',
        '#weight' => -5,
        '#default_value' => $selected_notes,
      );

      if ($tmp_disabled) {
        $form['actions']['cancel_view'] = array(
          '#type' => 'button',
          '#value' => t('Offline'),
        );
      }
      else {
        $form['actions']['cancel_view'] = array(
          '#type' => 'button',
          '#value' => t('Cancel'),
        );
      }

      if ($flag_edit) {
        // We're editing an existing shopping cart item.
        $form['actions']['submit']['#value'] = t('Save changes');
      }
      else {
        if ($tmp_disabled) {
          $form['actions']['submit'] = array(
            '#value' => t('Offline'),
          );
        }
        else {
          $form['actions']['submit']['#value'] = t('Add to Cart');
        }
      }
      $form['#submit'][] = 'stockunlocks_form_submit';
    }
    return $form;
  }
}

/**
 * Implements hook_form_after_build().
 */
function _stockunlocks_after_build($form, &$form_state) {
  if (!empty($form['attributes'][SU_AID_IMEI]) && $form['attributes'][SU_AID_IMEI] != NULL) {
    if (!empty($form_state['triggering_element']['#value'])) {
      if (strstr($form_state['triggering_element']['#value'], 'Choose')) {
        if ($form_state['values']['display_country'] == TRUE) {
          if (empty($form_state['values']['attributes'][SU_AID_COUNTRY])) {
            $form['attributes'][SU_AID_NETWORK]['#disabled'] = TRUE;
            $form['attributes'][SU_AID_NETWORK]['#description'] = t('Please make your choice above before changing this one.');
            $form['attributes']['continue_to_brand']['#disabled'] = TRUE;
          }
        }
        if ($form_state['values']['display_brand'] == TRUE) {
          if (empty($form_state['values']['attributes'][SU_AID_BRAND])) {
            $form['attributes'][SU_AID_MODEL]['#disabled'] = TRUE;
            $form['attributes'][SU_AID_MODEL]['#description'] = t('Please make your choice above before changing this one.');
            $form['attributes']['continue_to_icon']['#disabled'] = TRUE;
          }
        }
        return $form;
      }
    }
    $form['#validate'][] = '_stockunlocks_product_validate';
    return $form;
  }
}

/**
 * Executes custom form validation calls.
 */
function _stockunlocks_product_validate($form, &$form_state) {
  if (!empty($form['attributes'][SU_AID_IMEI]) && $form['attributes'][SU_AID_IMEI] != NULL) {
    // The Cancel button was clicked.
    if (!empty($form_state['triggering_element']['#value'])) {
      if ($form_state['triggering_element']['#value'] == 'Cancel' || $form_state['triggering_element']['#value'] == 'Offline') {
        if (!empty($_SESSION['$stockunlocks_$session_$cart_item_id'])) {
          unset($_SESSION['$stockunlocks_$session_$cart_item_id']);
        }
        drupal_set_message(t('Action Cancelled.'));
        drupal_goto('cart');
      }
    }
    $flag_continue_country = TRUE;
    $flag_continue_network = TRUE;
    $flag_continue_brand = TRUE;
    $flag_continue_model = TRUE;
    $flag_continue_imei = TRUE;
    $flag_continue_kbh_esn = TRUE;
    $flag_continue_activation_phone = TRUE;
    $flag_continue_email_response = TRUE;
    $flag_continue_email_confirm = TRUE;
    $flag_continue_mep = TRUE;
    $flag_msg_country = '';
    $flag_msg_network = '';
    $flag_msg_brand = '';
    $flag_msg_model = '';
    $flag_msg_imei = '';
    $flag_msg_kbh_esn = '';
    $flag_msg_activation_phone = '';
    $flag_msg_email = '';
    $flag_msg_mep = '';
    $chk_dup_imei = array();
    // If IsNetwork, then country and network is required.
    if (!empty($form_state['values']['$IsNetwork'])) {
      if ($form_state['values']['$IsNetwork'] == '1') {
        if (empty($form_state['values']['attributes'][SU_AID_COUNTRY]) || $form_state['values']['attributes'][SU_AID_COUNTRY] == '') {
          $flag_continue_country = FALSE;
          $flag_msg_country = t('Country is required. <br />');
        }
        if (empty($form_state['values']['attributes'][SU_AID_NETWORK]) || $form_state['values']['attributes'][SU_AID_NETWORK] == '') {
          $flag_continue_network = FALSE;
          $flag_msg_network = t('Network is required. <br />');
        }
      }
    }
    // If IsModel, then brand and model are required.
    if (!empty($form_state['values']['$IsModel'])) {
      if ($form_state['values']['$IsModel'] == '1') {
        if (empty($form_state['values']['attributes'][SU_AID_BRAND]) || $form_state['values']['attributes'][SU_AID_BRAND] == '') {
          $flag_continue_brand = FALSE;
          $flag_msg_brand = t('Brand is required. <br />');
        }
        if (empty($form_state['values']['attributes'][SU_AID_MODEL]) || $form_state['values']['attributes'][SU_AID_MODEL] == '') {
          $flag_continue_model = FALSE;
          $flag_msg_model = t('Model is required. <br />');
        }
      }
    }
    // If IsKBH, then KBH/ESN (serial number) is required.
    if (!empty($form_state['values']['$IsKBH'])) {
      if ($form_state['values']['$IsKBH'] == '1') {
        if (empty($form_state['values']['attributes'][SU_AID_KBH]) || $form_state['values']['attributes'][SU_AID_KBH] == '') {
          $flag_continue_kbh_esn = FALSE;
          $flag_msg_kbh_esn = t('ESN (Serial Number) is required. <br />');
        }
      }
    }
    // If is_activation, then the SIM card provisioned phone number is required.
    if (!empty($form_state['values']['$IsActivation'])) {
      if ($form_state['values']['$IsActivation'] == '1') {
        if (empty($form_state['values']['attributes'][SU_AID_PHONE_NUM]) || $form_state['values']['attributes'][SU_AID_PHONE_NUM] == '') {
          $flag_continue_activation_phone = FALSE;
          $flag_msg_activation_phone = t('Original SIM Phone Number is required. <br />');
        }
      }
    }
    // If IsMEP, then the MEP is required.
    if (!empty($form_state['values']['$IsMEP'])) {
      if ($form_state['values']['$IsMEP'] == '1') {
        if (empty($form_state['values']['attributes'][SU_AID_MEP]) || $form_state['values']['attributes'][SU_AID_MEP] == '') {
          $flag_continue_mep = FALSE;
          $flag_msg_mep = t('MEP is required. <br />');
        }
      }
    }
    // Confirm that there is no text in the IMEI textarea field.
    $text = filter_xss(trim($form_state['values']['attributes'][SU_AID_IMEI]));
    $imei_length = $form_state['values']['$SerialLength'];
    $text_area = explode("\n", $text);
    $qty_new = count($text_area);
    $_i = 0;
    foreach ($text_area as $line) {
      // Grab each line, then iterate through each char to ensure numeric.
      $line_trim = trim($line);
      $chk_dup_imei[] = $line_trim;

      if (strlen($line_trim) != $imei_length) {
        $flag_continue_imei = FALSE;
        if ($line_trim == '') {
          $flag_msg_imei = $flag_msg_imei . t('(no empty lines allowed) - ');
        }

        $flag_msg_imei = $flag_msg_imei . t('An IMEI entry should be @var1 digits in length ==> @var2 = @var3 digit(s)<br />',
                                          array(
                                            '@var1' => $imei_length,
                                            '@var2' => $line_trim,
                                            '@var3' => strlen($line_trim),
                                          ));
      }
      // Confirm that only numeric digits have been submitted.
      if (stockunlocks_is_digits($line_trim) != 1) {
        $flag_continue_imei = FALSE;
        $flag_msg_imei = $flag_msg_imei . t('An IMEI entry should only contain numeric values ==> @var<br />', array('@var' => $line_trim));
      }

      $imei = $line_trim;
      if (!empty($imei) && $imei != NULL) {
        if (strlen($line_trim) == 15) {
          // Check for a valid IMEI value.
          if (stockunlocks_check_imei($imei) == 0) {
            $flag_continue_imei = FALSE;
            $flag_msg_imei = $flag_msg_imei . t('@var is not a valid IMEI entry. <br />', array('@var' => $imei));
          }
        }
      }
    }

    // Confirm that there were no duplicate IMEI values submitted.
    if (count($chk_dup_imei) != count(array_unique($chk_dup_imei))) {
      $flag_continue_imei = FALSE;
      $flag_msg_imei = $flag_msg_imei . t('IMEI entries should not contain any duplicate values. <br />');
    }
    else {
      // Duplicate values do not exists.
    }

    $email_response = filter_xss(trim($form_state['values']['attributes'][SU_AID_EMAIL_RESPONSE]));
    $email_confirm = filter_xss(trim($form_state['values']['attributes'][SU_AID_EMAIL_CONFIRM]));

    if (!valid_email_address($email_response)) {
      $flag_continue_email_response = FALSE;
      $flag_msg_email = t('Sorry, the email address ==>@var is not valid. <br />', array('@var' => $email_response));
    }

    if ($email_response != $email_confirm) {
      $flag_continue_email_confirm = FALSE;
      $flag_msg_email = $flag_msg_email . t('Sorry, the email addresses must match: @var1 != @var2<br />',
                                          array(
                                            '@var1' => $email_response,
                                            '@var2' => $email_confirm,
                                          ));
    }

    if (!$flag_continue_country) {
      form_set_error("attributes][" . SU_AID_COUNTRY, $flag_msg_country);
    }

    if (!$flag_continue_network) {
      form_set_error("attributes][" . SU_AID_NETWORK, $flag_msg_network);
    }

    if (!$flag_continue_brand) {
      form_set_error("attributes][" . SU_AID_BRAND, $flag_msg_brand);
    }

    if (!$flag_continue_model) {
      form_set_error("attributes][" . SU_AID_MODEL, $flag_msg_model);
    }

    if (!$flag_continue_mep) {
      form_set_error("attributes][" . SU_AID_MEP, $flag_msg_mep);
    }

    if (!$flag_continue_imei) {
      form_set_error("attributes][" . SU_AID_IMEI, $flag_msg_imei);
    }

    if (!$flag_continue_email_response) {
      form_set_error("attributes][" . SU_AID_EMAIL_RESPONSE, $flag_msg_email);
    }

    if (!$flag_continue_email_confirm) {
      form_set_error("attributes][" . SU_AID_EMAIL_CONFIRM, $flag_msg_email);
    }

    if (!$flag_continue_activation_phone) {
      form_set_error("attributes][" . SU_AID_PHONE_NUM, $flag_msg_activation_phone);
    }

    if (!$flag_continue_kbh_esn) {
      form_set_error("attributes][" . SU_AID_KBH, $flag_msg_kbh_esn);
    }

    if ($form_state['values']['cart_data_attributes_only'] != serialize($form_state['values']['attributes'])) {
      $form_state['values']['qty'] = $qty_new;
    }
  }
}

/**
 * Implements hook_form_submit().
 */
function stockunlocks_form_submit($form, &$form_state) {
  if (!empty($form['attributes'][SU_AID_IMEI]) && $form['attributes'][SU_AID_IMEI] != NULL) {
    if (!empty($_SESSION['$stockunlocks_$session_$cart_item_id'])) {
      unset($_SESSION['$stockunlocks_$session_$cart_item_id']);
    }

    switch ($form_state['triggering_element']['#value']) {
      case t('Save changes'):
      case t('Add to Cart'):
        $items = uc_cart_get_contents();
        foreach ($items as $item) {
          if ($item->cart_item_id == $form_state['values']['cart_item_id']) {
            $nid = $form_state['values']['cart_nid'];
            $data = $item->data;
            // Make sure that we're dealing with the same product.
            // If not, create a new shopping cart item.
            // Just get the atttributes data and compare.
            // If they're the same, then this was an update.
            if (($form_state['values']['current_nid'] == $form_state['values']['cart_nid']) && ($form_state['values']['cart_data_attributes_only'] != serialize($form_state['values']['attributes']))) {
              uc_cart_remove_item($nid, NULL, $data);
            }
          }
        }
        return;

    }

    $items = uc_cart_get_contents();
    foreach ($items as $item) {
      $nid = $item->nid;
      $data = $item->data;
      // Rid the cart of spurious entries.
      if ($item->qty == 0) {
        uc_cart_remove_item($nid, NULL, $data);
      }
    }
    // Stay on the current screen with the open form.
    $form_state['rebuild'] = TRUE;
  }
}

/**
 * Returns an array of ajax commands related to country selection.
 *
 * @param array $form
 *   An associative array containing form values.
 *
 * @param array $form_state
 *   An associative array containing form state values.
 */
function stockunlocks_ajax_dropdown_country_callback($form, $form_state) {
  $commands = array();
  $commands[] = ajax_command_replace("#dropdown-network-replace", render($form['attributes'][SU_AID_NETWORK]));
  $commands[] = ajax_command_replace("#dropdown-brand-replace", render($form['attributes'][SU_AID_BRAND]));
  $commands[] = ajax_command_replace("#dropdown-model-replace", render($form['attributes'][SU_AID_MODEL]));
  $commands[] = ajax_command_replace("#dropdown-mep-replace", render($form['attributes'][SU_AID_MEP]));
  $ajax_array = array('#type' => 'ajax', '#commands' => $commands);
  return $ajax_array;
}

/**
 * Returns an array of ajax commands related to network selection.
 *
 * @param array $form
 *   An associative array containing form values.
 *
 * @param array $form_state
 *   An associative array containing form state values.
 */
function stockunlocks_ajax_dropdown_network_callback($form, $form_state) {
  $commands = array();
  $commands[] = ajax_command_replace("#dropdown-brand-replace", render($form['attributes'][SU_AID_BRAND]));
  $commands[] = ajax_command_replace("#dropdown-model-replace", render($form['attributes'][SU_AID_MODEL]));
  $commands[] = ajax_command_replace("#dropdown-mep-replace", render($form['attributes'][SU_AID_MEP]));
  $ajax_array = array('#type' => 'ajax', '#commands' => $commands);
  return $ajax_array;
}

/**
 * Returns an array of ajax commands related to brand selection.
 *
 * @param array $form
 *   An associative array containing form values.
 *
 * @param array $form_state
 *   An associative array containing form state values.
 */
function stockunlocks_ajax_dropdown_brand_callback($form, $form_state) {
  $commands = array();
  $commands[] = ajax_command_replace("#dropdown-network-replace", render($form['attributes'][SU_AID_NETWORK]));
  $commands[] = ajax_command_replace("#dropdown-model-replace", render($form['attributes'][SU_AID_MODEL]));
  $commands[] = ajax_command_replace("#dropdown-mep-replace", render($form['attributes'][SU_AID_MEP]));
  $commands[] = ajax_command_replace("#details-model-icon", render($form['icon_model']));
  $ajax_array = array('#type' => 'ajax', '#commands' => $commands);
  return $ajax_array;
}

/**
 * Returns an array of ajax commands related to model selection.
 *
 * @param array $form
 *   An associative array containing form values.
 *
 * @param array $form_state
 *   An associative array containing form state values.
 */
function stockunlocks_ajax_dropdown_model_callback($form, $form_state) {
  $commands = array();
  $commands[] = ajax_command_replace("#dropdown-network-replace", render($form['attributes'][SU_AID_NETWORK]));
  $commands[] = ajax_command_replace("#dropdown-brand-replace", render($form['attributes'][SU_AID_BRAND]));
  $commands[] = ajax_command_replace("#dropdown-mep-replace", render($form['attributes'][SU_AID_MEP]));
  $commands[] = ajax_command_replace("#details-model-icon", render($form['icon_model']));
  $ajax_array = array('#type' => 'ajax', '#commands' => $commands);
  return $ajax_array;
}

/**
 * Returns an array of ajax commands related to MEP selection.
 *
 * @param array $form
 *   An associative array containing form values.
 *
 * @param array $form_state
 *   An associative array containing form state values.
 */
function stockunlocks_ajax_dropdown_mep_callback($form, $form_state) {
  $commands = array();
  $commands[] = ajax_command_replace("#dropdown-network-replace", render($form['attributes'][SU_AID_NETWORK]));
  $commands[] = ajax_command_replace("#dropdown-brand-replace", render($form['attributes'][SU_AID_BRAND]));
  $commands[] = ajax_command_replace("#dropdown-model-replace", render($form['attributes'][SU_AID_MODEL]));
  $ajax_array = array('#type' => 'ajax', '#commands' => $commands);
  return $ajax_array;
}

/**
 * Returns an array of ajax commands related to model icon selection.
 *
 * @param array $form
 *   An associative array containing form values.
 *
 * @param array $form_state
 *   An associative array containing form state values.
 */
function stockunlocks_ajax_icon_model_callback($form, $form_state) {
  $commands = array();
  $commands[] = ajax_command_replace("#details-model-icon", render($form['icon_model']));
  $ajax_array = array('#type' => 'ajax', '#commands' => $commands);
  return $ajax_array;
}

/**
 * Returns an array, modifying the display of the Ubercart product image.
 *
 * @param int $nid
 *   The nid representing the Ubercart product.
 *
 * @param string $style
 *   The chosen image style: uc_product.
 */
function stockunlocks_product_get_picture($nid, $style = 'uc_product') {
  $product = node_load($nid);
  if (!$product) {
    return array();
  }
  $field_name = variable_get('uc_image_' . $product->type, 'uc_product_image');
  $output = array();
  if ($field_name && isset($product->$field_name)) {
    $elements = field_view_field('node', $product, $field_name, array(
      'label' => 'hidden',
      'type' => 'image',
      'settings' => array(
        'image_style' => $style,
      ),
    ));
    $output = isset($elements[0]) ? $elements[0] : array();
    if (isset($elements['#access'])) {
      $output['#access'] = $elements['#access'];
    }
  }
  return $output;
}
